#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenSpOperationResultQueryModel(object):

    def __init__(self):
        self._access_product_code = None
        self._alipay_account = None
        self._batch_no = None
        self._isv_scene_permissions = None
        self._merchant_no = None
        self._operate_type = None

    @property
    def access_product_code(self):
        return self._access_product_code

    @access_product_code.setter
    def access_product_code(self, value):
        self._access_product_code = value
    @property
    def alipay_account(self):
        return self._alipay_account

    @alipay_account.setter
    def alipay_account(self, value):
        self._alipay_account = value
    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def isv_scene_permissions(self):
        return self._isv_scene_permissions

    @isv_scene_permissions.setter
    def isv_scene_permissions(self, value):
        self._isv_scene_permissions = value
    @property
    def merchant_no(self):
        return self._merchant_no

    @merchant_no.setter
    def merchant_no(self, value):
        self._merchant_no = value
    @property
    def operate_type(self):
        return self._operate_type

    @operate_type.setter
    def operate_type(self, value):
        self._operate_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.access_product_code:
            if hasattr(self.access_product_code, 'to_alipay_dict'):
                params['access_product_code'] = self.access_product_code.to_alipay_dict()
            else:
                params['access_product_code'] = self.access_product_code
        if self.alipay_account:
            if hasattr(self.alipay_account, 'to_alipay_dict'):
                params['alipay_account'] = self.alipay_account.to_alipay_dict()
            else:
                params['alipay_account'] = self.alipay_account
        if self.batch_no:
            if hasattr(self.batch_no, 'to_alipay_dict'):
                params['batch_no'] = self.batch_no.to_alipay_dict()
            else:
                params['batch_no'] = self.batch_no
        if self.isv_scene_permissions:
            if hasattr(self.isv_scene_permissions, 'to_alipay_dict'):
                params['isv_scene_permissions'] = self.isv_scene_permissions.to_alipay_dict()
            else:
                params['isv_scene_permissions'] = self.isv_scene_permissions
        if self.merchant_no:
            if hasattr(self.merchant_no, 'to_alipay_dict'):
                params['merchant_no'] = self.merchant_no.to_alipay_dict()
            else:
                params['merchant_no'] = self.merchant_no
        if self.operate_type:
            if hasattr(self.operate_type, 'to_alipay_dict'):
                params['operate_type'] = self.operate_type.to_alipay_dict()
            else:
                params['operate_type'] = self.operate_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenSpOperationResultQueryModel()
        if 'access_product_code' in d:
            o.access_product_code = d['access_product_code']
        if 'alipay_account' in d:
            o.alipay_account = d['alipay_account']
        if 'batch_no' in d:
            o.batch_no = d['batch_no']
        if 'isv_scene_permissions' in d:
            o.isv_scene_permissions = d['isv_scene_permissions']
        if 'merchant_no' in d:
            o.merchant_no = d['merchant_no']
        if 'operate_type' in d:
            o.operate_type = d['operate_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaMerchantSubsidiariesApplyModel(object):

    def __init__(self):
        self._pid = None
        self._service_id = None
        self._smid = None
        self._sub_merchant_contact_number = None
        self._sub_merchant_jump_link = None
        self._sub_merchant_logo_url = None
        self._sub_merchant_name = None
        self._sub_pid = None

    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def service_id(self):
        return self._service_id

    @service_id.setter
    def service_id(self, value):
        self._service_id = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value
    @property
    def sub_merchant_contact_number(self):
        return self._sub_merchant_contact_number

    @sub_merchant_contact_number.setter
    def sub_merchant_contact_number(self, value):
        self._sub_merchant_contact_number = value
    @property
    def sub_merchant_jump_link(self):
        return self._sub_merchant_jump_link

    @sub_merchant_jump_link.setter
    def sub_merchant_jump_link(self, value):
        self._sub_merchant_jump_link = value
    @property
    def sub_merchant_logo_url(self):
        return self._sub_merchant_logo_url

    @sub_merchant_logo_url.setter
    def sub_merchant_logo_url(self, value):
        self._sub_merchant_logo_url = value
    @property
    def sub_merchant_name(self):
        return self._sub_merchant_name

    @sub_merchant_name.setter
    def sub_merchant_name(self, value):
        self._sub_merchant_name = value
    @property
    def sub_pid(self):
        return self._sub_pid

    @sub_pid.setter
    def sub_pid(self, value):
        self._sub_pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.service_id:
            if hasattr(self.service_id, 'to_alipay_dict'):
                params['service_id'] = self.service_id.to_alipay_dict()
            else:
                params['service_id'] = self.service_id
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        if self.sub_merchant_contact_number:
            if hasattr(self.sub_merchant_contact_number, 'to_alipay_dict'):
                params['sub_merchant_contact_number'] = self.sub_merchant_contact_number.to_alipay_dict()
            else:
                params['sub_merchant_contact_number'] = self.sub_merchant_contact_number
        if self.sub_merchant_jump_link:
            if hasattr(self.sub_merchant_jump_link, 'to_alipay_dict'):
                params['sub_merchant_jump_link'] = self.sub_merchant_jump_link.to_alipay_dict()
            else:
                params['sub_merchant_jump_link'] = self.sub_merchant_jump_link
        if self.sub_merchant_logo_url:
            if hasattr(self.sub_merchant_logo_url, 'to_alipay_dict'):
                params['sub_merchant_logo_url'] = self.sub_merchant_logo_url.to_alipay_dict()
            else:
                params['sub_merchant_logo_url'] = self.sub_merchant_logo_url
        if self.sub_merchant_name:
            if hasattr(self.sub_merchant_name, 'to_alipay_dict'):
                params['sub_merchant_name'] = self.sub_merchant_name.to_alipay_dict()
            else:
                params['sub_merchant_name'] = self.sub_merchant_name
        if self.sub_pid:
            if hasattr(self.sub_pid, 'to_alipay_dict'):
                params['sub_pid'] = self.sub_pid.to_alipay_dict()
            else:
                params['sub_pid'] = self.sub_pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaMerchantSubsidiariesApplyModel()
        if 'pid' in d:
            o.pid = d['pid']
        if 'service_id' in d:
            o.service_id = d['service_id']
        if 'smid' in d:
            o.smid = d['smid']
        if 'sub_merchant_contact_number' in d:
            o.sub_merchant_contact_number = d['sub_merchant_contact_number']
        if 'sub_merchant_jump_link' in d:
            o.sub_merchant_jump_link = d['sub_merchant_jump_link']
        if 'sub_merchant_logo_url' in d:
            o.sub_merchant_logo_url = d['sub_merchant_logo_url']
        if 'sub_merchant_name' in d:
            o.sub_merchant_name = d['sub_merchant_name']
        if 'sub_pid' in d:
            o.sub_pid = d['sub_pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCampaignUserActivityvoucherBatchqueryModel(object):

    def __init__(self):
        self._scene_code = None
        self._voucher_status = None

    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        if isinstance(value, list):
            self._scene_code = list()
            for i in value:
                self._scene_code.append(i)
    @property
    def voucher_status(self):
        return self._voucher_status

    @voucher_status.setter
    def voucher_status(self, value):
        self._voucher_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.scene_code:
            if isinstance(self.scene_code, list):
                for i in range(0, len(self.scene_code)):
                    element = self.scene_code[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.scene_code[i] = element.to_alipay_dict()
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.voucher_status:
            if hasattr(self.voucher_status, 'to_alipay_dict'):
                params['voucher_status'] = self.voucher_status.to_alipay_dict()
            else:
                params['voucher_status'] = self.voucher_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCampaignUserActivityvoucherBatchqueryModel()
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'voucher_status' in d:
            o.voucher_status = d['voucher_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialAntforestCarbondayQueryModel(object):

    def __init__(self):
        self._carbon_type = None
        self._day = None
        self._open_id = None
        self._user_id = None

    @property
    def carbon_type(self):
        return self._carbon_type

    @carbon_type.setter
    def carbon_type(self, value):
        if isinstance(value, list):
            self._carbon_type = list()
            for i in value:
                self._carbon_type.append(i)
    @property
    def day(self):
        return self._day

    @day.setter
    def day(self, value):
        self._day = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.carbon_type:
            if isinstance(self.carbon_type, list):
                for i in range(0, len(self.carbon_type)):
                    element = self.carbon_type[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.carbon_type[i] = element.to_alipay_dict()
            if hasattr(self.carbon_type, 'to_alipay_dict'):
                params['carbon_type'] = self.carbon_type.to_alipay_dict()
            else:
                params['carbon_type'] = self.carbon_type
        if self.day:
            if hasattr(self.day, 'to_alipay_dict'):
                params['day'] = self.day.to_alipay_dict()
            else:
                params['day'] = self.day
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialAntforestCarbondayQueryModel()
        if 'carbon_type' in d:
            o.carbon_type = d['carbon_type']
        if 'day' in d:
            o.day = d['day']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MemberBenefitInfo(object):

    def __init__(self):
        self._action_url = None
        self._icon_url = None
        self._title = None
        self._value = None

    @property
    def action_url(self):
        return self._action_url

    @action_url.setter
    def action_url(self, value):
        self._action_url = value
    @property
    def icon_url(self):
        return self._icon_url

    @icon_url.setter
    def icon_url(self, value):
        self._icon_url = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def value(self):
        return self._value

    @value.setter
    def value(self, value):
        self._value = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_url:
            if hasattr(self.action_url, 'to_alipay_dict'):
                params['action_url'] = self.action_url.to_alipay_dict()
            else:
                params['action_url'] = self.action_url
        if self.icon_url:
            if hasattr(self.icon_url, 'to_alipay_dict'):
                params['icon_url'] = self.icon_url.to_alipay_dict()
            else:
                params['icon_url'] = self.icon_url
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.value:
            if hasattr(self.value, 'to_alipay_dict'):
                params['value'] = self.value.to_alipay_dict()
            else:
                params['value'] = self.value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MemberBenefitInfo()
        if 'action_url' in d:
            o.action_url = d['action_url']
        if 'icon_url' in d:
            o.icon_url = d['icon_url']
        if 'title' in d:
            o.title = d['title']
        if 'value' in d:
            o.value = d['value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossProdAlcagmprodAgreementQueryModel(object):

    def __init__(self):
        self._agreement_id = None
        self._open_id = None
        self._out_sign_no = None
        self._product_cd = None
        self._user_id = None

    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_sign_no(self):
        return self._out_sign_no

    @out_sign_no.setter
    def out_sign_no(self, value):
        self._out_sign_no = value
    @property
    def product_cd(self):
        return self._product_cd

    @product_cd.setter
    def product_cd(self, value):
        self._product_cd = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_id:
            if hasattr(self.agreement_id, 'to_alipay_dict'):
                params['agreement_id'] = self.agreement_id.to_alipay_dict()
            else:
                params['agreement_id'] = self.agreement_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_sign_no:
            if hasattr(self.out_sign_no, 'to_alipay_dict'):
                params['out_sign_no'] = self.out_sign_no.to_alipay_dict()
            else:
                params['out_sign_no'] = self.out_sign_no
        if self.product_cd:
            if hasattr(self.product_cd, 'to_alipay_dict'):
                params['product_cd'] = self.product_cd.to_alipay_dict()
            else:
                params['product_cd'] = self.product_cd
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossProdAlcagmprodAgreementQueryModel()
        if 'agreement_id' in d:
            o.agreement_id = d['agreement_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_sign_no' in d:
            o.out_sign_no = d['out_sign_no']
        if 'product_cd' in d:
            o.product_cd = d['product_cd']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DeviceTradeInfoList(object):

    def __init__(self):
        self._biz_tid = None
        self._dau = None
        self._device_face_trade_dau = None
        self._device_face_trade_dau_d_value = None
        self._device_name = None
        self._device_sn = None
        self._device_status = None
        self._face_trade_cnt = None
        self._face_trd_amt = None
        self._face_trd_cnt_rate = None
        self._face_trd_user_cnt_rate = None
        self._face_trd_user_cnt_rate_d_value = None
        self._gmt_active = None
        self._iot_trd_up = None
        self._iot_trd_user_cnt = None
        self._iot_trd_user_cnt_d_value = None
        self._max_dt = None
        self._merchant_pid = None
        self._shop_id = None
        self._trade_amt = None
        self._trade_cnt = None

    @property
    def biz_tid(self):
        return self._biz_tid

    @biz_tid.setter
    def biz_tid(self, value):
        self._biz_tid = value
    @property
    def dau(self):
        return self._dau

    @dau.setter
    def dau(self, value):
        self._dau = value
    @property
    def device_face_trade_dau(self):
        return self._device_face_trade_dau

    @device_face_trade_dau.setter
    def device_face_trade_dau(self, value):
        self._device_face_trade_dau = value
    @property
    def device_face_trade_dau_d_value(self):
        return self._device_face_trade_dau_d_value

    @device_face_trade_dau_d_value.setter
    def device_face_trade_dau_d_value(self, value):
        self._device_face_trade_dau_d_value = value
    @property
    def device_name(self):
        return self._device_name

    @device_name.setter
    def device_name(self, value):
        self._device_name = value
    @property
    def device_sn(self):
        return self._device_sn

    @device_sn.setter
    def device_sn(self, value):
        self._device_sn = value
    @property
    def device_status(self):
        return self._device_status

    @device_status.setter
    def device_status(self, value):
        self._device_status = value
    @property
    def face_trade_cnt(self):
        return self._face_trade_cnt

    @face_trade_cnt.setter
    def face_trade_cnt(self, value):
        self._face_trade_cnt = value
    @property
    def face_trd_amt(self):
        return self._face_trd_amt

    @face_trd_amt.setter
    def face_trd_amt(self, value):
        self._face_trd_amt = value
    @property
    def face_trd_cnt_rate(self):
        return self._face_trd_cnt_rate

    @face_trd_cnt_rate.setter
    def face_trd_cnt_rate(self, value):
        self._face_trd_cnt_rate = value
    @property
    def face_trd_user_cnt_rate(self):
        return self._face_trd_user_cnt_rate

    @face_trd_user_cnt_rate.setter
    def face_trd_user_cnt_rate(self, value):
        self._face_trd_user_cnt_rate = value
    @property
    def face_trd_user_cnt_rate_d_value(self):
        return self._face_trd_user_cnt_rate_d_value

    @face_trd_user_cnt_rate_d_value.setter
    def face_trd_user_cnt_rate_d_value(self, value):
        self._face_trd_user_cnt_rate_d_value = value
    @property
    def gmt_active(self):
        return self._gmt_active

    @gmt_active.setter
    def gmt_active(self, value):
        self._gmt_active = value
    @property
    def iot_trd_up(self):
        return self._iot_trd_up

    @iot_trd_up.setter
    def iot_trd_up(self, value):
        self._iot_trd_up = value
    @property
    def iot_trd_user_cnt(self):
        return self._iot_trd_user_cnt

    @iot_trd_user_cnt.setter
    def iot_trd_user_cnt(self, value):
        self._iot_trd_user_cnt = value
    @property
    def iot_trd_user_cnt_d_value(self):
        return self._iot_trd_user_cnt_d_value

    @iot_trd_user_cnt_d_value.setter
    def iot_trd_user_cnt_d_value(self, value):
        self._iot_trd_user_cnt_d_value = value
    @property
    def max_dt(self):
        return self._max_dt

    @max_dt.setter
    def max_dt(self, value):
        self._max_dt = value
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def trade_amt(self):
        return self._trade_amt

    @trade_amt.setter
    def trade_amt(self, value):
        self._trade_amt = value
    @property
    def trade_cnt(self):
        return self._trade_cnt

    @trade_cnt.setter
    def trade_cnt(self, value):
        self._trade_cnt = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_tid:
            if hasattr(self.biz_tid, 'to_alipay_dict'):
                params['biz_tid'] = self.biz_tid.to_alipay_dict()
            else:
                params['biz_tid'] = self.biz_tid
        if self.dau:
            if hasattr(self.dau, 'to_alipay_dict'):
                params['dau'] = self.dau.to_alipay_dict()
            else:
                params['dau'] = self.dau
        if self.device_face_trade_dau:
            if hasattr(self.device_face_trade_dau, 'to_alipay_dict'):
                params['device_face_trade_dau'] = self.device_face_trade_dau.to_alipay_dict()
            else:
                params['device_face_trade_dau'] = self.device_face_trade_dau
        if self.device_face_trade_dau_d_value:
            if hasattr(self.device_face_trade_dau_d_value, 'to_alipay_dict'):
                params['device_face_trade_dau_d_value'] = self.device_face_trade_dau_d_value.to_alipay_dict()
            else:
                params['device_face_trade_dau_d_value'] = self.device_face_trade_dau_d_value
        if self.device_name:
            if hasattr(self.device_name, 'to_alipay_dict'):
                params['device_name'] = self.device_name.to_alipay_dict()
            else:
                params['device_name'] = self.device_name
        if self.device_sn:
            if hasattr(self.device_sn, 'to_alipay_dict'):
                params['device_sn'] = self.device_sn.to_alipay_dict()
            else:
                params['device_sn'] = self.device_sn
        if self.device_status:
            if hasattr(self.device_status, 'to_alipay_dict'):
                params['device_status'] = self.device_status.to_alipay_dict()
            else:
                params['device_status'] = self.device_status
        if self.face_trade_cnt:
            if hasattr(self.face_trade_cnt, 'to_alipay_dict'):
                params['face_trade_cnt'] = self.face_trade_cnt.to_alipay_dict()
            else:
                params['face_trade_cnt'] = self.face_trade_cnt
        if self.face_trd_amt:
            if hasattr(self.face_trd_amt, 'to_alipay_dict'):
                params['face_trd_amt'] = self.face_trd_amt.to_alipay_dict()
            else:
                params['face_trd_amt'] = self.face_trd_amt
        if self.face_trd_cnt_rate:
            if hasattr(self.face_trd_cnt_rate, 'to_alipay_dict'):
                params['face_trd_cnt_rate'] = self.face_trd_cnt_rate.to_alipay_dict()
            else:
                params['face_trd_cnt_rate'] = self.face_trd_cnt_rate
        if self.face_trd_user_cnt_rate:
            if hasattr(self.face_trd_user_cnt_rate, 'to_alipay_dict'):
                params['face_trd_user_cnt_rate'] = self.face_trd_user_cnt_rate.to_alipay_dict()
            else:
                params['face_trd_user_cnt_rate'] = self.face_trd_user_cnt_rate
        if self.face_trd_user_cnt_rate_d_value:
            if hasattr(self.face_trd_user_cnt_rate_d_value, 'to_alipay_dict'):
                params['face_trd_user_cnt_rate_d_value'] = self.face_trd_user_cnt_rate_d_value.to_alipay_dict()
            else:
                params['face_trd_user_cnt_rate_d_value'] = self.face_trd_user_cnt_rate_d_value
        if self.gmt_active:
            if hasattr(self.gmt_active, 'to_alipay_dict'):
                params['gmt_active'] = self.gmt_active.to_alipay_dict()
            else:
                params['gmt_active'] = self.gmt_active
        if self.iot_trd_up:
            if hasattr(self.iot_trd_up, 'to_alipay_dict'):
                params['iot_trd_up'] = self.iot_trd_up.to_alipay_dict()
            else:
                params['iot_trd_up'] = self.iot_trd_up
        if self.iot_trd_user_cnt:
            if hasattr(self.iot_trd_user_cnt, 'to_alipay_dict'):
                params['iot_trd_user_cnt'] = self.iot_trd_user_cnt.to_alipay_dict()
            else:
                params['iot_trd_user_cnt'] = self.iot_trd_user_cnt
        if self.iot_trd_user_cnt_d_value:
            if hasattr(self.iot_trd_user_cnt_d_value, 'to_alipay_dict'):
                params['iot_trd_user_cnt_d_value'] = self.iot_trd_user_cnt_d_value.to_alipay_dict()
            else:
                params['iot_trd_user_cnt_d_value'] = self.iot_trd_user_cnt_d_value
        if self.max_dt:
            if hasattr(self.max_dt, 'to_alipay_dict'):
                params['max_dt'] = self.max_dt.to_alipay_dict()
            else:
                params['max_dt'] = self.max_dt
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.trade_amt:
            if hasattr(self.trade_amt, 'to_alipay_dict'):
                params['trade_amt'] = self.trade_amt.to_alipay_dict()
            else:
                params['trade_amt'] = self.trade_amt
        if self.trade_cnt:
            if hasattr(self.trade_cnt, 'to_alipay_dict'):
                params['trade_cnt'] = self.trade_cnt.to_alipay_dict()
            else:
                params['trade_cnt'] = self.trade_cnt
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeviceTradeInfoList()
        if 'biz_tid' in d:
            o.biz_tid = d['biz_tid']
        if 'dau' in d:
            o.dau = d['dau']
        if 'device_face_trade_dau' in d:
            o.device_face_trade_dau = d['device_face_trade_dau']
        if 'device_face_trade_dau_d_value' in d:
            o.device_face_trade_dau_d_value = d['device_face_trade_dau_d_value']
        if 'device_name' in d:
            o.device_name = d['device_name']
        if 'device_sn' in d:
            o.device_sn = d['device_sn']
        if 'device_status' in d:
            o.device_status = d['device_status']
        if 'face_trade_cnt' in d:
            o.face_trade_cnt = d['face_trade_cnt']
        if 'face_trd_amt' in d:
            o.face_trd_amt = d['face_trd_amt']
        if 'face_trd_cnt_rate' in d:
            o.face_trd_cnt_rate = d['face_trd_cnt_rate']
        if 'face_trd_user_cnt_rate' in d:
            o.face_trd_user_cnt_rate = d['face_trd_user_cnt_rate']
        if 'face_trd_user_cnt_rate_d_value' in d:
            o.face_trd_user_cnt_rate_d_value = d['face_trd_user_cnt_rate_d_value']
        if 'gmt_active' in d:
            o.gmt_active = d['gmt_active']
        if 'iot_trd_up' in d:
            o.iot_trd_up = d['iot_trd_up']
        if 'iot_trd_user_cnt' in d:
            o.iot_trd_user_cnt = d['iot_trd_user_cnt']
        if 'iot_trd_user_cnt_d_value' in d:
            o.iot_trd_user_cnt_d_value = d['iot_trd_user_cnt_d_value']
        if 'max_dt' in d:
            o.max_dt = d['max_dt']
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'trade_amt' in d:
            o.trade_amt = d['trade_amt']
        if 'trade_cnt' in d:
            o.trade_cnt = d['trade_cnt']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GFAOpenAPIAccountingAcceptance(object):

    def __init__(self):
        self._amount_map = None
        self._biz_bill_nos_map = None
        self._biz_elements = None
        self._biz_ev_code = None
        self._biz_pd_code = None
        self._cnl_ev_code = None
        self._cnl_pd_code = None
        self._gmt_service = None
        self._high_amount_map = None
        self._inst_code = None
        self._memo = None
        self._out_business_no = None
        self._properties = None
        self._service_type = None
        self._sub_out_business_no = None
        self._system_origin = None
        self._tnt_inst_id = None

    @property
    def amount_map(self):
        return self._amount_map

    @amount_map.setter
    def amount_map(self, value):
        self._amount_map = value
    @property
    def biz_bill_nos_map(self):
        return self._biz_bill_nos_map

    @biz_bill_nos_map.setter
    def biz_bill_nos_map(self, value):
        self._biz_bill_nos_map = value
    @property
    def biz_elements(self):
        return self._biz_elements

    @biz_elements.setter
    def biz_elements(self, value):
        self._biz_elements = value
    @property
    def biz_ev_code(self):
        return self._biz_ev_code

    @biz_ev_code.setter
    def biz_ev_code(self, value):
        self._biz_ev_code = value
    @property
    def biz_pd_code(self):
        return self._biz_pd_code

    @biz_pd_code.setter
    def biz_pd_code(self, value):
        self._biz_pd_code = value
    @property
    def cnl_ev_code(self):
        return self._cnl_ev_code

    @cnl_ev_code.setter
    def cnl_ev_code(self, value):
        self._cnl_ev_code = value
    @property
    def cnl_pd_code(self):
        return self._cnl_pd_code

    @cnl_pd_code.setter
    def cnl_pd_code(self, value):
        self._cnl_pd_code = value
    @property
    def gmt_service(self):
        return self._gmt_service

    @gmt_service.setter
    def gmt_service(self, value):
        self._gmt_service = value
    @property
    def high_amount_map(self):
        return self._high_amount_map

    @high_amount_map.setter
    def high_amount_map(self, value):
        self._high_amount_map = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def out_business_no(self):
        return self._out_business_no

    @out_business_no.setter
    def out_business_no(self, value):
        self._out_business_no = value
    @property
    def properties(self):
        return self._properties

    @properties.setter
    def properties(self, value):
        self._properties = value
    @property
    def service_type(self):
        return self._service_type

    @service_type.setter
    def service_type(self, value):
        self._service_type = value
    @property
    def sub_out_business_no(self):
        return self._sub_out_business_no

    @sub_out_business_no.setter
    def sub_out_business_no(self, value):
        self._sub_out_business_no = value
    @property
    def system_origin(self):
        return self._system_origin

    @system_origin.setter
    def system_origin(self, value):
        self._system_origin = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount_map:
            if hasattr(self.amount_map, 'to_alipay_dict'):
                params['amount_map'] = self.amount_map.to_alipay_dict()
            else:
                params['amount_map'] = self.amount_map
        if self.biz_bill_nos_map:
            if hasattr(self.biz_bill_nos_map, 'to_alipay_dict'):
                params['biz_bill_nos_map'] = self.biz_bill_nos_map.to_alipay_dict()
            else:
                params['biz_bill_nos_map'] = self.biz_bill_nos_map
        if self.biz_elements:
            if hasattr(self.biz_elements, 'to_alipay_dict'):
                params['biz_elements'] = self.biz_elements.to_alipay_dict()
            else:
                params['biz_elements'] = self.biz_elements
        if self.biz_ev_code:
            if hasattr(self.biz_ev_code, 'to_alipay_dict'):
                params['biz_ev_code'] = self.biz_ev_code.to_alipay_dict()
            else:
                params['biz_ev_code'] = self.biz_ev_code
        if self.biz_pd_code:
            if hasattr(self.biz_pd_code, 'to_alipay_dict'):
                params['biz_pd_code'] = self.biz_pd_code.to_alipay_dict()
            else:
                params['biz_pd_code'] = self.biz_pd_code
        if self.cnl_ev_code:
            if hasattr(self.cnl_ev_code, 'to_alipay_dict'):
                params['cnl_ev_code'] = self.cnl_ev_code.to_alipay_dict()
            else:
                params['cnl_ev_code'] = self.cnl_ev_code
        if self.cnl_pd_code:
            if hasattr(self.cnl_pd_code, 'to_alipay_dict'):
                params['cnl_pd_code'] = self.cnl_pd_code.to_alipay_dict()
            else:
                params['cnl_pd_code'] = self.cnl_pd_code
        if self.gmt_service:
            if hasattr(self.gmt_service, 'to_alipay_dict'):
                params['gmt_service'] = self.gmt_service.to_alipay_dict()
            else:
                params['gmt_service'] = self.gmt_service
        if self.high_amount_map:
            if hasattr(self.high_amount_map, 'to_alipay_dict'):
                params['high_amount_map'] = self.high_amount_map.to_alipay_dict()
            else:
                params['high_amount_map'] = self.high_amount_map
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.out_business_no:
            if hasattr(self.out_business_no, 'to_alipay_dict'):
                params['out_business_no'] = self.out_business_no.to_alipay_dict()
            else:
                params['out_business_no'] = self.out_business_no
        if self.properties:
            if hasattr(self.properties, 'to_alipay_dict'):
                params['properties'] = self.properties.to_alipay_dict()
            else:
                params['properties'] = self.properties
        if self.service_type:
            if hasattr(self.service_type, 'to_alipay_dict'):
                params['service_type'] = self.service_type.to_alipay_dict()
            else:
                params['service_type'] = self.service_type
        if self.sub_out_business_no:
            if hasattr(self.sub_out_business_no, 'to_alipay_dict'):
                params['sub_out_business_no'] = self.sub_out_business_no.to_alipay_dict()
            else:
                params['sub_out_business_no'] = self.sub_out_business_no
        if self.system_origin:
            if hasattr(self.system_origin, 'to_alipay_dict'):
                params['system_origin'] = self.system_origin.to_alipay_dict()
            else:
                params['system_origin'] = self.system_origin
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GFAOpenAPIAccountingAcceptance()
        if 'amount_map' in d:
            o.amount_map = d['amount_map']
        if 'biz_bill_nos_map' in d:
            o.biz_bill_nos_map = d['biz_bill_nos_map']
        if 'biz_elements' in d:
            o.biz_elements = d['biz_elements']
        if 'biz_ev_code' in d:
            o.biz_ev_code = d['biz_ev_code']
        if 'biz_pd_code' in d:
            o.biz_pd_code = d['biz_pd_code']
        if 'cnl_ev_code' in d:
            o.cnl_ev_code = d['cnl_ev_code']
        if 'cnl_pd_code' in d:
            o.cnl_pd_code = d['cnl_pd_code']
        if 'gmt_service' in d:
            o.gmt_service = d['gmt_service']
        if 'high_amount_map' in d:
            o.high_amount_map = d['high_amount_map']
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'memo' in d:
            o.memo = d['memo']
        if 'out_business_no' in d:
            o.out_business_no = d['out_business_no']
        if 'properties' in d:
            o.properties = d['properties']
        if 'service_type' in d:
            o.service_type = d['service_type']
        if 'sub_out_business_no' in d:
            o.sub_out_business_no = d['sub_out_business_no']
        if 'system_origin' in d:
            o.system_origin = d['system_origin']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InstBillInfo(object):

    def __init__(self):
        self._balance = None
        self._bill_amount = None
        self._bill_date = None
        self._bill_id = None
        self._cache_key = None
        self._charge_type = None
        self._fine_amount = None

    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        self._balance = value
    @property
    def bill_amount(self):
        return self._bill_amount

    @bill_amount.setter
    def bill_amount(self, value):
        self._bill_amount = value
    @property
    def bill_date(self):
        return self._bill_date

    @bill_date.setter
    def bill_date(self, value):
        self._bill_date = value
    @property
    def bill_id(self):
        return self._bill_id

    @bill_id.setter
    def bill_id(self, value):
        self._bill_id = value
    @property
    def cache_key(self):
        return self._cache_key

    @cache_key.setter
    def cache_key(self, value):
        self._cache_key = value
    @property
    def charge_type(self):
        return self._charge_type

    @charge_type.setter
    def charge_type(self, value):
        self._charge_type = value
    @property
    def fine_amount(self):
        return self._fine_amount

    @fine_amount.setter
    def fine_amount(self, value):
        self._fine_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.balance:
            if hasattr(self.balance, 'to_alipay_dict'):
                params['balance'] = self.balance.to_alipay_dict()
            else:
                params['balance'] = self.balance
        if self.bill_amount:
            if hasattr(self.bill_amount, 'to_alipay_dict'):
                params['bill_amount'] = self.bill_amount.to_alipay_dict()
            else:
                params['bill_amount'] = self.bill_amount
        if self.bill_date:
            if hasattr(self.bill_date, 'to_alipay_dict'):
                params['bill_date'] = self.bill_date.to_alipay_dict()
            else:
                params['bill_date'] = self.bill_date
        if self.bill_id:
            if hasattr(self.bill_id, 'to_alipay_dict'):
                params['bill_id'] = self.bill_id.to_alipay_dict()
            else:
                params['bill_id'] = self.bill_id
        if self.cache_key:
            if hasattr(self.cache_key, 'to_alipay_dict'):
                params['cache_key'] = self.cache_key.to_alipay_dict()
            else:
                params['cache_key'] = self.cache_key
        if self.charge_type:
            if hasattr(self.charge_type, 'to_alipay_dict'):
                params['charge_type'] = self.charge_type.to_alipay_dict()
            else:
                params['charge_type'] = self.charge_type
        if self.fine_amount:
            if hasattr(self.fine_amount, 'to_alipay_dict'):
                params['fine_amount'] = self.fine_amount.to_alipay_dict()
            else:
                params['fine_amount'] = self.fine_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InstBillInfo()
        if 'balance' in d:
            o.balance = d['balance']
        if 'bill_amount' in d:
            o.bill_amount = d['bill_amount']
        if 'bill_date' in d:
            o.bill_date = d['bill_date']
        if 'bill_id' in d:
            o.bill_id = d['bill_id']
        if 'cache_key' in d:
            o.cache_key = d['cache_key']
        if 'charge_type' in d:
            o.charge_type = d['charge_type']
        if 'fine_amount' in d:
            o.fine_amount = d['fine_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayIserviceCognitiveOcrDriverlicenseQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceCognitiveOcrDriverlicenseQueryResponse, self).__init__()
        self._addr = None
        self._end_date = None
        self._error_content = None
        self._name = None
        self._num = None
        self._request_id = None
        self._sex = None
        self._start_date = None
        self._success = None
        self._trace_id = None
        self._vehicle_type = None

    @property
    def addr(self):
        return self._addr

    @addr.setter
    def addr(self, value):
        self._addr = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def error_content(self):
        return self._error_content

    @error_content.setter
    def error_content(self, value):
        self._error_content = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def num(self):
        return self._num

    @num.setter
    def num(self, value):
        self._num = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def sex(self):
        return self._sex

    @sex.setter
    def sex(self, value):
        self._sex = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value
    @property
    def vehicle_type(self):
        return self._vehicle_type

    @vehicle_type.setter
    def vehicle_type(self, value):
        self._vehicle_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceCognitiveOcrDriverlicenseQueryResponse, self).parse_response_content(response_content)
        if 'addr' in response:
            self.addr = response['addr']
        if 'end_date' in response:
            self.end_date = response['end_date']
        if 'error_content' in response:
            self.error_content = response['error_content']
        if 'name' in response:
            self.name = response['name']
        if 'num' in response:
            self.num = response['num']
        if 'request_id' in response:
            self.request_id = response['request_id']
        if 'sex' in response:
            self.sex = response['sex']
        if 'start_date' in response:
            self.start_date = response['start_date']
        if 'success' in response:
            self.success = response['success']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']
        if 'vehicle_type' in response:
            self.vehicle_type = response['vehicle_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.KbdishSpecGroup import KbdishSpecGroup


class KoubeiCateringDishSpecgroupQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiCateringDishSpecgroupQueryResponse, self).__init__()
        self._merchant_id = None
        self._spec_group_list = None

    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def spec_group_list(self):
        return self._spec_group_list

    @spec_group_list.setter
    def spec_group_list(self, value):
        if isinstance(value, list):
            self._spec_group_list = list()
            for i in value:
                if isinstance(i, KbdishSpecGroup):
                    self._spec_group_list.append(i)
                else:
                    self._spec_group_list.append(KbdishSpecGroup.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiCateringDishSpecgroupQueryResponse, self).parse_response_content(response_content)
        if 'merchant_id' in response:
            self.merchant_id = response['merchant_id']
        if 'spec_group_list' in response:
            self.spec_group_list = response['spec_group_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BizResult(object):

    def __init__(self):
        self._encoded_result_obj = None
        self._error_code = None
        self._error_msg = None
        self._error_view_msg = None
        self._need_retry = None
        self._success = None

    @property
    def encoded_result_obj(self):
        return self._encoded_result_obj

    @encoded_result_obj.setter
    def encoded_result_obj(self, value):
        self._encoded_result_obj = value
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_msg(self):
        return self._error_msg

    @error_msg.setter
    def error_msg(self, value):
        self._error_msg = value
    @property
    def error_view_msg(self):
        return self._error_view_msg

    @error_view_msg.setter
    def error_view_msg(self, value):
        self._error_view_msg = value
    @property
    def need_retry(self):
        return self._need_retry

    @need_retry.setter
    def need_retry(self, value):
        self._need_retry = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value


    def to_alipay_dict(self):
        params = dict()
        if self.encoded_result_obj:
            if hasattr(self.encoded_result_obj, 'to_alipay_dict'):
                params['encoded_result_obj'] = self.encoded_result_obj.to_alipay_dict()
            else:
                params['encoded_result_obj'] = self.encoded_result_obj
        if self.error_code:
            if hasattr(self.error_code, 'to_alipay_dict'):
                params['error_code'] = self.error_code.to_alipay_dict()
            else:
                params['error_code'] = self.error_code
        if self.error_msg:
            if hasattr(self.error_msg, 'to_alipay_dict'):
                params['error_msg'] = self.error_msg.to_alipay_dict()
            else:
                params['error_msg'] = self.error_msg
        if self.error_view_msg:
            if hasattr(self.error_view_msg, 'to_alipay_dict'):
                params['error_view_msg'] = self.error_view_msg.to_alipay_dict()
            else:
                params['error_view_msg'] = self.error_view_msg
        if self.need_retry:
            if hasattr(self.need_retry, 'to_alipay_dict'):
                params['need_retry'] = self.need_retry.to_alipay_dict()
            else:
                params['need_retry'] = self.need_retry
        if self.success:
            if hasattr(self.success, 'to_alipay_dict'):
                params['success'] = self.success.to_alipay_dict()
            else:
                params['success'] = self.success
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BizResult()
        if 'encoded_result_obj' in d:
            o.encoded_result_obj = d['encoded_result_obj']
        if 'error_code' in d:
            o.error_code = d['error_code']
        if 'error_msg' in d:
            o.error_msg = d['error_msg']
        if 'error_view_msg' in d:
            o.error_view_msg = d['error_view_msg']
        if 'need_retry' in d:
            o.need_retry = d['need_retry']
        if 'success' in d:
            o.success = d['success']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IsvLogisticsInfo import IsvLogisticsInfo


class AlipayMerchantWeikeInvoiceNotifyModel(object):

    def __init__(self):
        self._apply_id = None
        self._feedback_code = None
        self._feedback_msg = None
        self._feedback_result = None
        self._invoice_kind = None
        self._logistics_info = None

    @property
    def apply_id(self):
        return self._apply_id

    @apply_id.setter
    def apply_id(self, value):
        self._apply_id = value
    @property
    def feedback_code(self):
        return self._feedback_code

    @feedback_code.setter
    def feedback_code(self, value):
        self._feedback_code = value
    @property
    def feedback_msg(self):
        return self._feedback_msg

    @feedback_msg.setter
    def feedback_msg(self, value):
        self._feedback_msg = value
    @property
    def feedback_result(self):
        return self._feedback_result

    @feedback_result.setter
    def feedback_result(self, value):
        self._feedback_result = value
    @property
    def invoice_kind(self):
        return self._invoice_kind

    @invoice_kind.setter
    def invoice_kind(self, value):
        self._invoice_kind = value
    @property
    def logistics_info(self):
        return self._logistics_info

    @logistics_info.setter
    def logistics_info(self, value):
        if isinstance(value, list):
            self._logistics_info = list()
            for i in value:
                if isinstance(i, IsvLogisticsInfo):
                    self._logistics_info.append(i)
                else:
                    self._logistics_info.append(IsvLogisticsInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.apply_id:
            if hasattr(self.apply_id, 'to_alipay_dict'):
                params['apply_id'] = self.apply_id.to_alipay_dict()
            else:
                params['apply_id'] = self.apply_id
        if self.feedback_code:
            if hasattr(self.feedback_code, 'to_alipay_dict'):
                params['feedback_code'] = self.feedback_code.to_alipay_dict()
            else:
                params['feedback_code'] = self.feedback_code
        if self.feedback_msg:
            if hasattr(self.feedback_msg, 'to_alipay_dict'):
                params['feedback_msg'] = self.feedback_msg.to_alipay_dict()
            else:
                params['feedback_msg'] = self.feedback_msg
        if self.feedback_result:
            if hasattr(self.feedback_result, 'to_alipay_dict'):
                params['feedback_result'] = self.feedback_result.to_alipay_dict()
            else:
                params['feedback_result'] = self.feedback_result
        if self.invoice_kind:
            if hasattr(self.invoice_kind, 'to_alipay_dict'):
                params['invoice_kind'] = self.invoice_kind.to_alipay_dict()
            else:
                params['invoice_kind'] = self.invoice_kind
        if self.logistics_info:
            if isinstance(self.logistics_info, list):
                for i in range(0, len(self.logistics_info)):
                    element = self.logistics_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.logistics_info[i] = element.to_alipay_dict()
            if hasattr(self.logistics_info, 'to_alipay_dict'):
                params['logistics_info'] = self.logistics_info.to_alipay_dict()
            else:
                params['logistics_info'] = self.logistics_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantWeikeInvoiceNotifyModel()
        if 'apply_id' in d:
            o.apply_id = d['apply_id']
        if 'feedback_code' in d:
            o.feedback_code = d['feedback_code']
        if 'feedback_msg' in d:
            o.feedback_msg = d['feedback_msg']
        if 'feedback_result' in d:
            o.feedback_result = d['feedback_result']
        if 'invoice_kind' in d:
            o.invoice_kind = d['invoice_kind']
        if 'logistics_info' in d:
            o.logistics_info = d['logistics_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ApprovalTravelerDTO import ApprovalTravelerDTO
from alipay.aop.api.domain.ApprovalTripDTO import ApprovalTripDTO


class AlipayCommerceEcApprovalQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEcApprovalQueryResponse, self).__init__()
        self._approval_result = None
        self._approval_traveler_dto_list = None
        self._approval_trip_dto_list = None
        self._employee_id = None
        self._enterprise_id = None
        self._platform_approval_id = None
        self._purpose = None

    @property
    def approval_result(self):
        return self._approval_result

    @approval_result.setter
    def approval_result(self, value):
        self._approval_result = value
    @property
    def approval_traveler_dto_list(self):
        return self._approval_traveler_dto_list

    @approval_traveler_dto_list.setter
    def approval_traveler_dto_list(self, value):
        if isinstance(value, list):
            self._approval_traveler_dto_list = list()
            for i in value:
                if isinstance(i, ApprovalTravelerDTO):
                    self._approval_traveler_dto_list.append(i)
                else:
                    self._approval_traveler_dto_list.append(ApprovalTravelerDTO.from_alipay_dict(i))
    @property
    def approval_trip_dto_list(self):
        return self._approval_trip_dto_list

    @approval_trip_dto_list.setter
    def approval_trip_dto_list(self, value):
        if isinstance(value, list):
            self._approval_trip_dto_list = list()
            for i in value:
                if isinstance(i, ApprovalTripDTO):
                    self._approval_trip_dto_list.append(i)
                else:
                    self._approval_trip_dto_list.append(ApprovalTripDTO.from_alipay_dict(i))
    @property
    def employee_id(self):
        return self._employee_id

    @employee_id.setter
    def employee_id(self, value):
        self._employee_id = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def platform_approval_id(self):
        return self._platform_approval_id

    @platform_approval_id.setter
    def platform_approval_id(self, value):
        self._platform_approval_id = value
    @property
    def purpose(self):
        return self._purpose

    @purpose.setter
    def purpose(self, value):
        self._purpose = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEcApprovalQueryResponse, self).parse_response_content(response_content)
        if 'approval_result' in response:
            self.approval_result = response['approval_result']
        if 'approval_traveler_dto_list' in response:
            self.approval_traveler_dto_list = response['approval_traveler_dto_list']
        if 'approval_trip_dto_list' in response:
            self.approval_trip_dto_list = response['approval_trip_dto_list']
        if 'employee_id' in response:
            self.employee_id = response['employee_id']
        if 'enterprise_id' in response:
            self.enterprise_id = response['enterprise_id']
        if 'platform_approval_id' in response:
            self.platform_approval_id = response['platform_approval_id']
        if 'purpose' in response:
            self.purpose = response['purpose']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsSceneInspetprodSubscribeQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsSceneInspetprodSubscribeQueryResponse, self).__init__()
        self._subscribe = None

    @property
    def subscribe(self):
        return self._subscribe

    @subscribe.setter
    def subscribe(self, value):
        self._subscribe = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsSceneInspetprodSubscribeQueryResponse, self).parse_response_content(response_content)
        if 'subscribe' in response:
            self.subscribe = response['subscribe']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SceneConfigQueryDTO import SceneConfigQueryDTO


class AlipayCommerceEducateSceneConfigQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEducateSceneConfigQueryResponse, self).__init__()
        self._scene_config_infos = None

    @property
    def scene_config_infos(self):
        return self._scene_config_infos

    @scene_config_infos.setter
    def scene_config_infos(self, value):
        if isinstance(value, list):
            self._scene_config_infos = list()
            for i in value:
                if isinstance(i, SceneConfigQueryDTO):
                    self._scene_config_infos.append(i)
                else:
                    self._scene_config_infos.append(SceneConfigQueryDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEducateSceneConfigQueryResponse, self).parse_response_content(response_content)
        if 'scene_config_infos' in response:
            self.scene_config_infos = response['scene_config_infos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DeliveryAgencyMerchantInfo import DeliveryAgencyMerchantInfo
from alipay.aop.api.domain.DeliveryConfig import DeliveryConfig


class AlipayMarketingActivityDeliveryQueryModel(object):

    def __init__(self):
        self._belong_merchant_info = None
        self._delivery_config_list = None
        self._delivery_id = None
        self._merchant_access_mode = None

    @property
    def belong_merchant_info(self):
        return self._belong_merchant_info

    @belong_merchant_info.setter
    def belong_merchant_info(self, value):
        if isinstance(value, DeliveryAgencyMerchantInfo):
            self._belong_merchant_info = value
        else:
            self._belong_merchant_info = DeliveryAgencyMerchantInfo.from_alipay_dict(value)
    @property
    def delivery_config_list(self):
        return self._delivery_config_list

    @delivery_config_list.setter
    def delivery_config_list(self, value):
        if isinstance(value, list):
            self._delivery_config_list = list()
            for i in value:
                if isinstance(i, DeliveryConfig):
                    self._delivery_config_list.append(i)
                else:
                    self._delivery_config_list.append(DeliveryConfig.from_alipay_dict(i))
    @property
    def delivery_id(self):
        return self._delivery_id

    @delivery_id.setter
    def delivery_id(self, value):
        self._delivery_id = value
    @property
    def merchant_access_mode(self):
        return self._merchant_access_mode

    @merchant_access_mode.setter
    def merchant_access_mode(self, value):
        self._merchant_access_mode = value


    def to_alipay_dict(self):
        params = dict()
        if self.belong_merchant_info:
            if hasattr(self.belong_merchant_info, 'to_alipay_dict'):
                params['belong_merchant_info'] = self.belong_merchant_info.to_alipay_dict()
            else:
                params['belong_merchant_info'] = self.belong_merchant_info
        if self.delivery_config_list:
            if isinstance(self.delivery_config_list, list):
                for i in range(0, len(self.delivery_config_list)):
                    element = self.delivery_config_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.delivery_config_list[i] = element.to_alipay_dict()
            if hasattr(self.delivery_config_list, 'to_alipay_dict'):
                params['delivery_config_list'] = self.delivery_config_list.to_alipay_dict()
            else:
                params['delivery_config_list'] = self.delivery_config_list
        if self.delivery_id:
            if hasattr(self.delivery_id, 'to_alipay_dict'):
                params['delivery_id'] = self.delivery_id.to_alipay_dict()
            else:
                params['delivery_id'] = self.delivery_id
        if self.merchant_access_mode:
            if hasattr(self.merchant_access_mode, 'to_alipay_dict'):
                params['merchant_access_mode'] = self.merchant_access_mode.to_alipay_dict()
            else:
                params['merchant_access_mode'] = self.merchant_access_mode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingActivityDeliveryQueryModel()
        if 'belong_merchant_info' in d:
            o.belong_merchant_info = d['belong_merchant_info']
        if 'delivery_config_list' in d:
            o.delivery_config_list = d['delivery_config_list']
        if 'delivery_id' in d:
            o.delivery_id = d['delivery_id']
        if 'merchant_access_mode' in d:
            o.merchant_access_mode = d['merchant_access_mode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayBusinessItemInventoryExternalSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBusinessItemInventoryExternalSyncResponse, self).__init__()
        self._item_ids = None
        self._request_id = None

    @property
    def item_ids(self):
        return self._item_ids

    @item_ids.setter
    def item_ids(self, value):
        if isinstance(value, list):
            self._item_ids = list()
            for i in value:
                self._item_ids.append(i)
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayBusinessItemInventoryExternalSyncResponse, self).parse_response_content(response_content)
        if 'item_ids' in response:
            self.item_ids = response['item_ids']
        if 'request_id' in response:
            self.request_id = response['request_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppFacepayBillPayModel(object):

    def __init__(self):
        self._bill_date = None
        self._bill_key = None
        self._biz_type = None
        self._charge_inst = None
        self._extend_field = None
        self._fine_amount = None
        self._inst_no = None
        self._out_order_no = None
        self._pay_amount = None
        self._pid = None
        self._sub_biz_type = None
        self._user_identity_code = None

    @property
    def bill_date(self):
        return self._bill_date

    @bill_date.setter
    def bill_date(self, value):
        self._bill_date = value
    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        self._extend_field = value
    @property
    def fine_amount(self):
        return self._fine_amount

    @fine_amount.setter
    def fine_amount(self, value):
        self._fine_amount = value
    @property
    def inst_no(self):
        return self._inst_no

    @inst_no.setter
    def inst_no(self, value):
        self._inst_no = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value
    @property
    def user_identity_code(self):
        return self._user_identity_code

    @user_identity_code.setter
    def user_identity_code(self, value):
        self._user_identity_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_date:
            if hasattr(self.bill_date, 'to_alipay_dict'):
                params['bill_date'] = self.bill_date.to_alipay_dict()
            else:
                params['bill_date'] = self.bill_date
        if self.bill_key:
            if hasattr(self.bill_key, 'to_alipay_dict'):
                params['bill_key'] = self.bill_key.to_alipay_dict()
            else:
                params['bill_key'] = self.bill_key
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.charge_inst:
            if hasattr(self.charge_inst, 'to_alipay_dict'):
                params['charge_inst'] = self.charge_inst.to_alipay_dict()
            else:
                params['charge_inst'] = self.charge_inst
        if self.extend_field:
            if hasattr(self.extend_field, 'to_alipay_dict'):
                params['extend_field'] = self.extend_field.to_alipay_dict()
            else:
                params['extend_field'] = self.extend_field
        if self.fine_amount:
            if hasattr(self.fine_amount, 'to_alipay_dict'):
                params['fine_amount'] = self.fine_amount.to_alipay_dict()
            else:
                params['fine_amount'] = self.fine_amount
        if self.inst_no:
            if hasattr(self.inst_no, 'to_alipay_dict'):
                params['inst_no'] = self.inst_no.to_alipay_dict()
            else:
                params['inst_no'] = self.inst_no
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        if self.user_identity_code:
            if hasattr(self.user_identity_code, 'to_alipay_dict'):
                params['user_identity_code'] = self.user_identity_code.to_alipay_dict()
            else:
                params['user_identity_code'] = self.user_identity_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppFacepayBillPayModel()
        if 'bill_date' in d:
            o.bill_date = d['bill_date']
        if 'bill_key' in d:
            o.bill_key = d['bill_key']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'charge_inst' in d:
            o.charge_inst = d['charge_inst']
        if 'extend_field' in d:
            o.extend_field = d['extend_field']
        if 'fine_amount' in d:
            o.fine_amount = d['fine_amount']
        if 'inst_no' in d:
            o.inst_no = d['inst_no']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        if 'pid' in d:
            o.pid = d['pid']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        if 'user_identity_code' in d:
            o.user_identity_code = d['user_identity_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PublicMessageInfo import PublicMessageInfo


class AlipayOpenPublicMessageQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenPublicMessageQueryResponse, self).__init__()
        self._list = None

    @property
    def list(self):
        return self._list

    @list.setter
    def list(self, value):
        if isinstance(value, list):
            self._list = list()
            for i in value:
                if isinstance(i, PublicMessageInfo):
                    self._list.append(i)
                else:
                    self._list.append(PublicMessageInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenPublicMessageQueryResponse, self).parse_response_content(response_content)
        if 'list' in response:
            self.list = response['list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.VoucherUseDetailResultInfo import VoucherUseDetailResultInfo


class AlipayMarketingActivityOrdervoucherUseResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingActivityOrdervoucherUseResponse, self).__init__()
        self._activity_id = None
        self._voucher_use_detail_result_info = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def voucher_use_detail_result_info(self):
        return self._voucher_use_detail_result_info

    @voucher_use_detail_result_info.setter
    def voucher_use_detail_result_info(self, value):
        if isinstance(value, VoucherUseDetailResultInfo):
            self._voucher_use_detail_result_info = value
        else:
            self._voucher_use_detail_result_info = VoucherUseDetailResultInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingActivityOrdervoucherUseResponse, self).parse_response_content(response_content)
        if 'activity_id' in response:
            self.activity_id = response['activity_id']
        if 'voucher_use_detail_result_info' in response:
            self.voucher_use_detail_result_info = response['voucher_use_detail_result_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MerchantInvoiceUKDTO import MerchantInvoiceUKDTO


class AlipayEbppInvoiceMerchantApplyModifyModel(object):

    def __init__(self):
        self._apply_id = None
        self._apply_result_memo = None
        self._apply_status = None
        self._attach_invoices = None
        self._batch_id = None

    @property
    def apply_id(self):
        return self._apply_id

    @apply_id.setter
    def apply_id(self, value):
        self._apply_id = value
    @property
    def apply_result_memo(self):
        return self._apply_result_memo

    @apply_result_memo.setter
    def apply_result_memo(self, value):
        self._apply_result_memo = value
    @property
    def apply_status(self):
        return self._apply_status

    @apply_status.setter
    def apply_status(self, value):
        self._apply_status = value
    @property
    def attach_invoices(self):
        return self._attach_invoices

    @attach_invoices.setter
    def attach_invoices(self, value):
        if isinstance(value, list):
            self._attach_invoices = list()
            for i in value:
                if isinstance(i, MerchantInvoiceUKDTO):
                    self._attach_invoices.append(i)
                else:
                    self._attach_invoices.append(MerchantInvoiceUKDTO.from_alipay_dict(i))
    @property
    def batch_id(self):
        return self._batch_id

    @batch_id.setter
    def batch_id(self, value):
        self._batch_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_id:
            if hasattr(self.apply_id, 'to_alipay_dict'):
                params['apply_id'] = self.apply_id.to_alipay_dict()
            else:
                params['apply_id'] = self.apply_id
        if self.apply_result_memo:
            if hasattr(self.apply_result_memo, 'to_alipay_dict'):
                params['apply_result_memo'] = self.apply_result_memo.to_alipay_dict()
            else:
                params['apply_result_memo'] = self.apply_result_memo
        if self.apply_status:
            if hasattr(self.apply_status, 'to_alipay_dict'):
                params['apply_status'] = self.apply_status.to_alipay_dict()
            else:
                params['apply_status'] = self.apply_status
        if self.attach_invoices:
            if isinstance(self.attach_invoices, list):
                for i in range(0, len(self.attach_invoices)):
                    element = self.attach_invoices[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.attach_invoices[i] = element.to_alipay_dict()
            if hasattr(self.attach_invoices, 'to_alipay_dict'):
                params['attach_invoices'] = self.attach_invoices.to_alipay_dict()
            else:
                params['attach_invoices'] = self.attach_invoices
        if self.batch_id:
            if hasattr(self.batch_id, 'to_alipay_dict'):
                params['batch_id'] = self.batch_id.to_alipay_dict()
            else:
                params['batch_id'] = self.batch_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceMerchantApplyModifyModel()
        if 'apply_id' in d:
            o.apply_id = d['apply_id']
        if 'apply_result_memo' in d:
            o.apply_result_memo = d['apply_result_memo']
        if 'apply_status' in d:
            o.apply_status = d['apply_status']
        if 'attach_invoices' in d:
            o.attach_invoices = d['attach_invoices']
        if 'batch_id' in d:
            o.batch_id = d['batch_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KeyWordInfo(object):

    def __init__(self):
        self._apply_no = None
        self._audit_key_word = None
        self._audit_reason = None
        self._audit_time = None
        self._config_id = None
        self._gmt_create = None
        self._key_word = None
        self._status = None

    @property
    def apply_no(self):
        return self._apply_no

    @apply_no.setter
    def apply_no(self, value):
        self._apply_no = value
    @property
    def audit_key_word(self):
        return self._audit_key_word

    @audit_key_word.setter
    def audit_key_word(self, value):
        self._audit_key_word = value
    @property
    def audit_reason(self):
        return self._audit_reason

    @audit_reason.setter
    def audit_reason(self, value):
        self._audit_reason = value
    @property
    def audit_time(self):
        return self._audit_time

    @audit_time.setter
    def audit_time(self, value):
        self._audit_time = value
    @property
    def config_id(self):
        return self._config_id

    @config_id.setter
    def config_id(self, value):
        self._config_id = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def key_word(self):
        return self._key_word

    @key_word.setter
    def key_word(self, value):
        self._key_word = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_no:
            if hasattr(self.apply_no, 'to_alipay_dict'):
                params['apply_no'] = self.apply_no.to_alipay_dict()
            else:
                params['apply_no'] = self.apply_no
        if self.audit_key_word:
            if hasattr(self.audit_key_word, 'to_alipay_dict'):
                params['audit_key_word'] = self.audit_key_word.to_alipay_dict()
            else:
                params['audit_key_word'] = self.audit_key_word
        if self.audit_reason:
            if hasattr(self.audit_reason, 'to_alipay_dict'):
                params['audit_reason'] = self.audit_reason.to_alipay_dict()
            else:
                params['audit_reason'] = self.audit_reason
        if self.audit_time:
            if hasattr(self.audit_time, 'to_alipay_dict'):
                params['audit_time'] = self.audit_time.to_alipay_dict()
            else:
                params['audit_time'] = self.audit_time
        if self.config_id:
            if hasattr(self.config_id, 'to_alipay_dict'):
                params['config_id'] = self.config_id.to_alipay_dict()
            else:
                params['config_id'] = self.config_id
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.key_word:
            if hasattr(self.key_word, 'to_alipay_dict'):
                params['key_word'] = self.key_word.to_alipay_dict()
            else:
                params['key_word'] = self.key_word
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KeyWordInfo()
        if 'apply_no' in d:
            o.apply_no = d['apply_no']
        if 'audit_key_word' in d:
            o.audit_key_word = d['audit_key_word']
        if 'audit_reason' in d:
            o.audit_reason = d['audit_reason']
        if 'audit_time' in d:
            o.audit_time = d['audit_time']
        if 'config_id' in d:
            o.config_id = d['config_id']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'key_word' in d:
            o.key_word = d['key_word']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OrderDataDistributeInfo import OrderDataDistributeInfo
from alipay.aop.api.domain.OrderDataSyncSuggestion import OrderDataSyncSuggestion


class AlipayMerchantOrderSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMerchantOrderSyncResponse, self).__init__()
        self._distribute_result = None
        self._order_id = None
        self._order_status = None
        self._record_id = None
        self._sync_suggestions = None

    @property
    def distribute_result(self):
        return self._distribute_result

    @distribute_result.setter
    def distribute_result(self, value):
        if isinstance(value, list):
            self._distribute_result = list()
            for i in value:
                if isinstance(i, OrderDataDistributeInfo):
                    self._distribute_result.append(i)
                else:
                    self._distribute_result.append(OrderDataDistributeInfo.from_alipay_dict(i))
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def record_id(self):
        return self._record_id

    @record_id.setter
    def record_id(self, value):
        self._record_id = value
    @property
    def sync_suggestions(self):
        return self._sync_suggestions

    @sync_suggestions.setter
    def sync_suggestions(self, value):
        if isinstance(value, list):
            self._sync_suggestions = list()
            for i in value:
                if isinstance(i, OrderDataSyncSuggestion):
                    self._sync_suggestions.append(i)
                else:
                    self._sync_suggestions.append(OrderDataSyncSuggestion.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayMerchantOrderSyncResponse, self).parse_response_content(response_content)
        if 'distribute_result' in response:
            self.distribute_result = response['distribute_result']
        if 'order_id' in response:
            self.order_id = response['order_id']
        if 'order_status' in response:
            self.order_status = response['order_status']
        if 'record_id' in response:
            self.record_id = response['record_id']
        if 'sync_suggestions' in response:
            self.sync_suggestions = response['sync_suggestions']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MiniappBrandAuditResult(object):

    def __init__(self):
        self._brand_id = None
        self._brand_name = None
        self._brand_status = None
        self._has_brand = None
        self._invalid_reason = None
        self._reject_reason = None

    @property
    def brand_id(self):
        return self._brand_id

    @brand_id.setter
    def brand_id(self, value):
        self._brand_id = value
    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def brand_status(self):
        return self._brand_status

    @brand_status.setter
    def brand_status(self, value):
        self._brand_status = value
    @property
    def has_brand(self):
        return self._has_brand

    @has_brand.setter
    def has_brand(self, value):
        self._has_brand = value
    @property
    def invalid_reason(self):
        return self._invalid_reason

    @invalid_reason.setter
    def invalid_reason(self, value):
        self._invalid_reason = value
    @property
    def reject_reason(self):
        return self._reject_reason

    @reject_reason.setter
    def reject_reason(self, value):
        self._reject_reason = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_id:
            if hasattr(self.brand_id, 'to_alipay_dict'):
                params['brand_id'] = self.brand_id.to_alipay_dict()
            else:
                params['brand_id'] = self.brand_id
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.brand_status:
            if hasattr(self.brand_status, 'to_alipay_dict'):
                params['brand_status'] = self.brand_status.to_alipay_dict()
            else:
                params['brand_status'] = self.brand_status
        if self.has_brand:
            if hasattr(self.has_brand, 'to_alipay_dict'):
                params['has_brand'] = self.has_brand.to_alipay_dict()
            else:
                params['has_brand'] = self.has_brand
        if self.invalid_reason:
            if hasattr(self.invalid_reason, 'to_alipay_dict'):
                params['invalid_reason'] = self.invalid_reason.to_alipay_dict()
            else:
                params['invalid_reason'] = self.invalid_reason
        if self.reject_reason:
            if hasattr(self.reject_reason, 'to_alipay_dict'):
                params['reject_reason'] = self.reject_reason.to_alipay_dict()
            else:
                params['reject_reason'] = self.reject_reason
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MiniappBrandAuditResult()
        if 'brand_id' in d:
            o.brand_id = d['brand_id']
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'brand_status' in d:
            o.brand_status = d['brand_status']
        if 'has_brand' in d:
            o.has_brand = d['has_brand']
        if 'invalid_reason' in d:
            o.invalid_reason = d['invalid_reason']
        if 'reject_reason' in d:
            o.reject_reason = d['reject_reason']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ExternalPoiInfo import ExternalPoiInfo


class AlipayEbppCommunityCommunityinfoCreateModel(object):

    def __init__(self):
        self._alias = None
        self._city = None
        self._community_adcode = None
        self._community_adcode_name = None
        self._community_short_name = None
        self._county = None
        self._county_name = None
        self._hot_line = None
        self._hot_line_end = None
        self._hot_line_start = None
        self._name = None
        self._out_community_id = None
        self._pois = None
        self._province = None
        self._street_adcode = None
        self._street_adcode_name = None
        self._support_type = None
        self._verify_type = None

    @property
    def alias(self):
        return self._alias

    @alias.setter
    def alias(self, value):
        self._alias = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def community_adcode(self):
        return self._community_adcode

    @community_adcode.setter
    def community_adcode(self, value):
        self._community_adcode = value
    @property
    def community_adcode_name(self):
        return self._community_adcode_name

    @community_adcode_name.setter
    def community_adcode_name(self, value):
        self._community_adcode_name = value
    @property
    def community_short_name(self):
        return self._community_short_name

    @community_short_name.setter
    def community_short_name(self, value):
        self._community_short_name = value
    @property
    def county(self):
        return self._county

    @county.setter
    def county(self, value):
        self._county = value
    @property
    def county_name(self):
        return self._county_name

    @county_name.setter
    def county_name(self, value):
        self._county_name = value
    @property
    def hot_line(self):
        return self._hot_line

    @hot_line.setter
    def hot_line(self, value):
        self._hot_line = value
    @property
    def hot_line_end(self):
        return self._hot_line_end

    @hot_line_end.setter
    def hot_line_end(self, value):
        self._hot_line_end = value
    @property
    def hot_line_start(self):
        return self._hot_line_start

    @hot_line_start.setter
    def hot_line_start(self, value):
        self._hot_line_start = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def out_community_id(self):
        return self._out_community_id

    @out_community_id.setter
    def out_community_id(self, value):
        self._out_community_id = value
    @property
    def pois(self):
        return self._pois

    @pois.setter
    def pois(self, value):
        if isinstance(value, list):
            self._pois = list()
            for i in value:
                if isinstance(i, ExternalPoiInfo):
                    self._pois.append(i)
                else:
                    self._pois.append(ExternalPoiInfo.from_alipay_dict(i))
    @property
    def province(self):
        return self._province

    @province.setter
    def province(self, value):
        self._province = value
    @property
    def street_adcode(self):
        return self._street_adcode

    @street_adcode.setter
    def street_adcode(self, value):
        self._street_adcode = value
    @property
    def street_adcode_name(self):
        return self._street_adcode_name

    @street_adcode_name.setter
    def street_adcode_name(self, value):
        self._street_adcode_name = value
    @property
    def support_type(self):
        return self._support_type

    @support_type.setter
    def support_type(self, value):
        self._support_type = value
    @property
    def verify_type(self):
        return self._verify_type

    @verify_type.setter
    def verify_type(self, value):
        self._verify_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.alias:
            if hasattr(self.alias, 'to_alipay_dict'):
                params['alias'] = self.alias.to_alipay_dict()
            else:
                params['alias'] = self.alias
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.community_adcode:
            if hasattr(self.community_adcode, 'to_alipay_dict'):
                params['community_adcode'] = self.community_adcode.to_alipay_dict()
            else:
                params['community_adcode'] = self.community_adcode
        if self.community_adcode_name:
            if hasattr(self.community_adcode_name, 'to_alipay_dict'):
                params['community_adcode_name'] = self.community_adcode_name.to_alipay_dict()
            else:
                params['community_adcode_name'] = self.community_adcode_name
        if self.community_short_name:
            if hasattr(self.community_short_name, 'to_alipay_dict'):
                params['community_short_name'] = self.community_short_name.to_alipay_dict()
            else:
                params['community_short_name'] = self.community_short_name
        if self.county:
            if hasattr(self.county, 'to_alipay_dict'):
                params['county'] = self.county.to_alipay_dict()
            else:
                params['county'] = self.county
        if self.county_name:
            if hasattr(self.county_name, 'to_alipay_dict'):
                params['county_name'] = self.county_name.to_alipay_dict()
            else:
                params['county_name'] = self.county_name
        if self.hot_line:
            if hasattr(self.hot_line, 'to_alipay_dict'):
                params['hot_line'] = self.hot_line.to_alipay_dict()
            else:
                params['hot_line'] = self.hot_line
        if self.hot_line_end:
            if hasattr(self.hot_line_end, 'to_alipay_dict'):
                params['hot_line_end'] = self.hot_line_end.to_alipay_dict()
            else:
                params['hot_line_end'] = self.hot_line_end
        if self.hot_line_start:
            if hasattr(self.hot_line_start, 'to_alipay_dict'):
                params['hot_line_start'] = self.hot_line_start.to_alipay_dict()
            else:
                params['hot_line_start'] = self.hot_line_start
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.out_community_id:
            if hasattr(self.out_community_id, 'to_alipay_dict'):
                params['out_community_id'] = self.out_community_id.to_alipay_dict()
            else:
                params['out_community_id'] = self.out_community_id
        if self.pois:
            if isinstance(self.pois, list):
                for i in range(0, len(self.pois)):
                    element = self.pois[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pois[i] = element.to_alipay_dict()
            if hasattr(self.pois, 'to_alipay_dict'):
                params['pois'] = self.pois.to_alipay_dict()
            else:
                params['pois'] = self.pois
        if self.province:
            if hasattr(self.province, 'to_alipay_dict'):
                params['province'] = self.province.to_alipay_dict()
            else:
                params['province'] = self.province
        if self.street_adcode:
            if hasattr(self.street_adcode, 'to_alipay_dict'):
                params['street_adcode'] = self.street_adcode.to_alipay_dict()
            else:
                params['street_adcode'] = self.street_adcode
        if self.street_adcode_name:
            if hasattr(self.street_adcode_name, 'to_alipay_dict'):
                params['street_adcode_name'] = self.street_adcode_name.to_alipay_dict()
            else:
                params['street_adcode_name'] = self.street_adcode_name
        if self.support_type:
            if hasattr(self.support_type, 'to_alipay_dict'):
                params['support_type'] = self.support_type.to_alipay_dict()
            else:
                params['support_type'] = self.support_type
        if self.verify_type:
            if hasattr(self.verify_type, 'to_alipay_dict'):
                params['verify_type'] = self.verify_type.to_alipay_dict()
            else:
                params['verify_type'] = self.verify_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppCommunityCommunityinfoCreateModel()
        if 'alias' in d:
            o.alias = d['alias']
        if 'city' in d:
            o.city = d['city']
        if 'community_adcode' in d:
            o.community_adcode = d['community_adcode']
        if 'community_adcode_name' in d:
            o.community_adcode_name = d['community_adcode_name']
        if 'community_short_name' in d:
            o.community_short_name = d['community_short_name']
        if 'county' in d:
            o.county = d['county']
        if 'county_name' in d:
            o.county_name = d['county_name']
        if 'hot_line' in d:
            o.hot_line = d['hot_line']
        if 'hot_line_end' in d:
            o.hot_line_end = d['hot_line_end']
        if 'hot_line_start' in d:
            o.hot_line_start = d['hot_line_start']
        if 'name' in d:
            o.name = d['name']
        if 'out_community_id' in d:
            o.out_community_id = d['out_community_id']
        if 'pois' in d:
            o.pois = d['pois']
        if 'province' in d:
            o.province = d['province']
        if 'street_adcode' in d:
            o.street_adcode = d['street_adcode']
        if 'street_adcode_name' in d:
            o.street_adcode_name = d['street_adcode_name']
        if 'support_type' in d:
            o.support_type = d['support_type']
        if 'verify_type' in d:
            o.verify_type = d['verify_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.RecommendBankInfo import RecommendBankInfo


class AlipayTradeServiceRecommendbankQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeServiceRecommendbankQueryResponse, self).__init__()
        self._recommend_bank_infos = None

    @property
    def recommend_bank_infos(self):
        return self._recommend_bank_infos

    @recommend_bank_infos.setter
    def recommend_bank_infos(self, value):
        if isinstance(value, list):
            self._recommend_bank_infos = list()
            for i in value:
                if isinstance(i, RecommendBankInfo):
                    self._recommend_bank_infos.append(i)
                else:
                    self._recommend_bank_infos.append(RecommendBankInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayTradeServiceRecommendbankQueryResponse, self).parse_response_content(response_content)
        if 'recommend_bank_infos' in response:
            self.recommend_bank_infos = response['recommend_bank_infos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KoubeiItemDescription import KoubeiItemDescription
from alipay.aop.api.domain.KoubeiTradeVoucherItemTemplete import KoubeiTradeVoucherItemTemplete


class ItemQueryResponse(object):

    def __init__(self):
        self._category_id = None
        self._cover = None
        self._descriptions = None
        self._gmt_end = None
        self._gmt_start = None
        self._inventory = None
        self._item_id = None
        self._item_status = None
        self._item_type = None
        self._memo = None
        self._original_price = None
        self._pic_coll = None
        self._picture_details = None
        self._price = None
        self._price_mode = None
        self._shop_ids = None
        self._subject = None
        self._tb_cover = None
        self._trade_voucher_item_template = None
        self._weight = None

    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def cover(self):
        return self._cover

    @cover.setter
    def cover(self, value):
        self._cover = value
    @property
    def descriptions(self):
        return self._descriptions

    @descriptions.setter
    def descriptions(self, value):
        if isinstance(value, list):
            self._descriptions = list()
            for i in value:
                if isinstance(i, KoubeiItemDescription):
                    self._descriptions.append(i)
                else:
                    self._descriptions.append(KoubeiItemDescription.from_alipay_dict(i))
    @property
    def gmt_end(self):
        return self._gmt_end

    @gmt_end.setter
    def gmt_end(self, value):
        self._gmt_end = value
    @property
    def gmt_start(self):
        return self._gmt_start

    @gmt_start.setter
    def gmt_start(self, value):
        self._gmt_start = value
    @property
    def inventory(self):
        return self._inventory

    @inventory.setter
    def inventory(self, value):
        self._inventory = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_status(self):
        return self._item_status

    @item_status.setter
    def item_status(self, value):
        self._item_status = value
    @property
    def item_type(self):
        return self._item_type

    @item_type.setter
    def item_type(self, value):
        self._item_type = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def pic_coll(self):
        return self._pic_coll

    @pic_coll.setter
    def pic_coll(self, value):
        if isinstance(value, list):
            self._pic_coll = list()
            for i in value:
                self._pic_coll.append(i)
    @property
    def picture_details(self):
        return self._picture_details

    @picture_details.setter
    def picture_details(self, value):
        self._picture_details = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def price_mode(self):
        return self._price_mode

    @price_mode.setter
    def price_mode(self, value):
        self._price_mode = value
    @property
    def shop_ids(self):
        return self._shop_ids

    @shop_ids.setter
    def shop_ids(self, value):
        self._shop_ids = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value
    @property
    def tb_cover(self):
        return self._tb_cover

    @tb_cover.setter
    def tb_cover(self, value):
        self._tb_cover = value
    @property
    def trade_voucher_item_template(self):
        return self._trade_voucher_item_template

    @trade_voucher_item_template.setter
    def trade_voucher_item_template(self, value):
        if isinstance(value, KoubeiTradeVoucherItemTemplete):
            self._trade_voucher_item_template = value
        else:
            self._trade_voucher_item_template = KoubeiTradeVoucherItemTemplete.from_alipay_dict(value)
    @property
    def weight(self):
        return self._weight

    @weight.setter
    def weight(self, value):
        self._weight = value


    def to_alipay_dict(self):
        params = dict()
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.cover:
            if hasattr(self.cover, 'to_alipay_dict'):
                params['cover'] = self.cover.to_alipay_dict()
            else:
                params['cover'] = self.cover
        if self.descriptions:
            if isinstance(self.descriptions, list):
                for i in range(0, len(self.descriptions)):
                    element = self.descriptions[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.descriptions[i] = element.to_alipay_dict()
            if hasattr(self.descriptions, 'to_alipay_dict'):
                params['descriptions'] = self.descriptions.to_alipay_dict()
            else:
                params['descriptions'] = self.descriptions
        if self.gmt_end:
            if hasattr(self.gmt_end, 'to_alipay_dict'):
                params['gmt_end'] = self.gmt_end.to_alipay_dict()
            else:
                params['gmt_end'] = self.gmt_end
        if self.gmt_start:
            if hasattr(self.gmt_start, 'to_alipay_dict'):
                params['gmt_start'] = self.gmt_start.to_alipay_dict()
            else:
                params['gmt_start'] = self.gmt_start
        if self.inventory:
            if hasattr(self.inventory, 'to_alipay_dict'):
                params['inventory'] = self.inventory.to_alipay_dict()
            else:
                params['inventory'] = self.inventory
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.item_status:
            if hasattr(self.item_status, 'to_alipay_dict'):
                params['item_status'] = self.item_status.to_alipay_dict()
            else:
                params['item_status'] = self.item_status
        if self.item_type:
            if hasattr(self.item_type, 'to_alipay_dict'):
                params['item_type'] = self.item_type.to_alipay_dict()
            else:
                params['item_type'] = self.item_type
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.original_price:
            if hasattr(self.original_price, 'to_alipay_dict'):
                params['original_price'] = self.original_price.to_alipay_dict()
            else:
                params['original_price'] = self.original_price
        if self.pic_coll:
            if isinstance(self.pic_coll, list):
                for i in range(0, len(self.pic_coll)):
                    element = self.pic_coll[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pic_coll[i] = element.to_alipay_dict()
            if hasattr(self.pic_coll, 'to_alipay_dict'):
                params['pic_coll'] = self.pic_coll.to_alipay_dict()
            else:
                params['pic_coll'] = self.pic_coll
        if self.picture_details:
            if hasattr(self.picture_details, 'to_alipay_dict'):
                params['picture_details'] = self.picture_details.to_alipay_dict()
            else:
                params['picture_details'] = self.picture_details
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.price_mode:
            if hasattr(self.price_mode, 'to_alipay_dict'):
                params['price_mode'] = self.price_mode.to_alipay_dict()
            else:
                params['price_mode'] = self.price_mode
        if self.shop_ids:
            if hasattr(self.shop_ids, 'to_alipay_dict'):
                params['shop_ids'] = self.shop_ids.to_alipay_dict()
            else:
                params['shop_ids'] = self.shop_ids
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        if self.tb_cover:
            if hasattr(self.tb_cover, 'to_alipay_dict'):
                params['tb_cover'] = self.tb_cover.to_alipay_dict()
            else:
                params['tb_cover'] = self.tb_cover
        if self.trade_voucher_item_template:
            if hasattr(self.trade_voucher_item_template, 'to_alipay_dict'):
                params['trade_voucher_item_template'] = self.trade_voucher_item_template.to_alipay_dict()
            else:
                params['trade_voucher_item_template'] = self.trade_voucher_item_template
        if self.weight:
            if hasattr(self.weight, 'to_alipay_dict'):
                params['weight'] = self.weight.to_alipay_dict()
            else:
                params['weight'] = self.weight
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ItemQueryResponse()
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'cover' in d:
            o.cover = d['cover']
        if 'descriptions' in d:
            o.descriptions = d['descriptions']
        if 'gmt_end' in d:
            o.gmt_end = d['gmt_end']
        if 'gmt_start' in d:
            o.gmt_start = d['gmt_start']
        if 'inventory' in d:
            o.inventory = d['inventory']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'item_status' in d:
            o.item_status = d['item_status']
        if 'item_type' in d:
            o.item_type = d['item_type']
        if 'memo' in d:
            o.memo = d['memo']
        if 'original_price' in d:
            o.original_price = d['original_price']
        if 'pic_coll' in d:
            o.pic_coll = d['pic_coll']
        if 'picture_details' in d:
            o.picture_details = d['picture_details']
        if 'price' in d:
            o.price = d['price']
        if 'price_mode' in d:
            o.price_mode = d['price_mode']
        if 'shop_ids' in d:
            o.shop_ids = d['shop_ids']
        if 'subject' in d:
            o.subject = d['subject']
        if 'tb_cover' in d:
            o.tb_cover = d['tb_cover']
        if 'trade_voucher_item_template' in d:
            o.trade_voucher_item_template = d['trade_voucher_item_template']
        if 'weight' in d:
            o.weight = d['weight']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.DeviceResultInfo import DeviceResultInfo


class AlipayUserAccountDeviceInfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserAccountDeviceInfoQueryResponse, self).__init__()
        self._device_infos = None
        self._device_type = None
        self._encrypt_type = None
        self._result_code = None

    @property
    def device_infos(self):
        return self._device_infos

    @device_infos.setter
    def device_infos(self, value):
        if isinstance(value, list):
            self._device_infos = list()
            for i in value:
                if isinstance(i, DeviceResultInfo):
                    self._device_infos.append(i)
                else:
                    self._device_infos.append(DeviceResultInfo.from_alipay_dict(i))
    @property
    def device_type(self):
        return self._device_type

    @device_type.setter
    def device_type(self, value):
        self._device_type = value
    @property
    def encrypt_type(self):
        return self._encrypt_type

    @encrypt_type.setter
    def encrypt_type(self, value):
        self._encrypt_type = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserAccountDeviceInfoQueryResponse, self).parse_response_content(response_content)
        if 'device_infos' in response:
            self.device_infos = response['device_infos']
        if 'device_type' in response:
            self.device_type = response['device_type']
        if 'encrypt_type' in response:
            self.encrypt_type = response['encrypt_type']
        if 'result_code' in response:
            self.result_code = response['result_code']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GravityParam(object):

    def __init__(self):
        self._content = None
        self._property = None

    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def property(self):
        return self._property

    @property.setter
    def property(self, value):
        self._property = value


    def to_alipay_dict(self):
        params = dict()
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.property:
            if hasattr(self.property, 'to_alipay_dict'):
                params['property'] = self.property.to_alipay_dict()
            else:
                params['property'] = self.property
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GravityParam()
        if 'content' in d:
            o.content = d['content']
        if 'property' in d:
            o.property = d['property']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PrizeBaseInfo import PrizeBaseInfo
from alipay.aop.api.domain.TaskBaseInfo import TaskBaseInfo
from alipay.aop.api.domain.TaskMaterialInfo import TaskMaterialInfo
from alipay.aop.api.domain.PrizeBaseInfo import PrizeBaseInfo


class TaskFullInfo(object):

    def __init__(self):
        self._access_limit_count = None
        self._last_acc_time = None
        self._last_complete_time = None
        self._last_receive_expire_time = None
        self._last_signup_expire_time = None
        self._last_signup_time = None
        self._need_sign_up = None
        self._period_current_complete_num = None
        self._period_total_complete_num = None
        self._periodic_accessed_num = None
        self._periodic_dimension = None
        self._prize_detail_list = None
        self._send_camp_trigger_type = None
        self._task_base_info = None
        self._task_id = None
        self._task_material = None
        self._task_process_status = None
        self._valid_prize_list = None

    @property
    def access_limit_count(self):
        return self._access_limit_count

    @access_limit_count.setter
    def access_limit_count(self, value):
        self._access_limit_count = value
    @property
    def last_acc_time(self):
        return self._last_acc_time

    @last_acc_time.setter
    def last_acc_time(self, value):
        self._last_acc_time = value
    @property
    def last_complete_time(self):
        return self._last_complete_time

    @last_complete_time.setter
    def last_complete_time(self, value):
        self._last_complete_time = value
    @property
    def last_receive_expire_time(self):
        return self._last_receive_expire_time

    @last_receive_expire_time.setter
    def last_receive_expire_time(self, value):
        self._last_receive_expire_time = value
    @property
    def last_signup_expire_time(self):
        return self._last_signup_expire_time

    @last_signup_expire_time.setter
    def last_signup_expire_time(self, value):
        self._last_signup_expire_time = value
    @property
    def last_signup_time(self):
        return self._last_signup_time

    @last_signup_time.setter
    def last_signup_time(self, value):
        self._last_signup_time = value
    @property
    def need_sign_up(self):
        return self._need_sign_up

    @need_sign_up.setter
    def need_sign_up(self, value):
        self._need_sign_up = value
    @property
    def period_current_complete_num(self):
        return self._period_current_complete_num

    @period_current_complete_num.setter
    def period_current_complete_num(self, value):
        self._period_current_complete_num = value
    @property
    def period_total_complete_num(self):
        return self._period_total_complete_num

    @period_total_complete_num.setter
    def period_total_complete_num(self, value):
        self._period_total_complete_num = value
    @property
    def periodic_accessed_num(self):
        return self._periodic_accessed_num

    @periodic_accessed_num.setter
    def periodic_accessed_num(self, value):
        self._periodic_accessed_num = value
    @property
    def periodic_dimension(self):
        return self._periodic_dimension

    @periodic_dimension.setter
    def periodic_dimension(self, value):
        self._periodic_dimension = value
    @property
    def prize_detail_list(self):
        return self._prize_detail_list

    @prize_detail_list.setter
    def prize_detail_list(self, value):
        if isinstance(value, list):
            self._prize_detail_list = list()
            for i in value:
                if isinstance(i, PrizeBaseInfo):
                    self._prize_detail_list.append(i)
                else:
                    self._prize_detail_list.append(PrizeBaseInfo.from_alipay_dict(i))
    @property
    def send_camp_trigger_type(self):
        return self._send_camp_trigger_type

    @send_camp_trigger_type.setter
    def send_camp_trigger_type(self, value):
        self._send_camp_trigger_type = value
    @property
    def task_base_info(self):
        return self._task_base_info

    @task_base_info.setter
    def task_base_info(self, value):
        if isinstance(value, TaskBaseInfo):
            self._task_base_info = value
        else:
            self._task_base_info = TaskBaseInfo.from_alipay_dict(value)
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value
    @property
    def task_material(self):
        return self._task_material

    @task_material.setter
    def task_material(self, value):
        if isinstance(value, TaskMaterialInfo):
            self._task_material = value
        else:
            self._task_material = TaskMaterialInfo.from_alipay_dict(value)
    @property
    def task_process_status(self):
        return self._task_process_status

    @task_process_status.setter
    def task_process_status(self, value):
        self._task_process_status = value
    @property
    def valid_prize_list(self):
        return self._valid_prize_list

    @valid_prize_list.setter
    def valid_prize_list(self, value):
        if isinstance(value, list):
            self._valid_prize_list = list()
            for i in value:
                if isinstance(i, PrizeBaseInfo):
                    self._valid_prize_list.append(i)
                else:
                    self._valid_prize_list.append(PrizeBaseInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.access_limit_count:
            if hasattr(self.access_limit_count, 'to_alipay_dict'):
                params['access_limit_count'] = self.access_limit_count.to_alipay_dict()
            else:
                params['access_limit_count'] = self.access_limit_count
        if self.last_acc_time:
            if hasattr(self.last_acc_time, 'to_alipay_dict'):
                params['last_acc_time'] = self.last_acc_time.to_alipay_dict()
            else:
                params['last_acc_time'] = self.last_acc_time
        if self.last_complete_time:
            if hasattr(self.last_complete_time, 'to_alipay_dict'):
                params['last_complete_time'] = self.last_complete_time.to_alipay_dict()
            else:
                params['last_complete_time'] = self.last_complete_time
        if self.last_receive_expire_time:
            if hasattr(self.last_receive_expire_time, 'to_alipay_dict'):
                params['last_receive_expire_time'] = self.last_receive_expire_time.to_alipay_dict()
            else:
                params['last_receive_expire_time'] = self.last_receive_expire_time
        if self.last_signup_expire_time:
            if hasattr(self.last_signup_expire_time, 'to_alipay_dict'):
                params['last_signup_expire_time'] = self.last_signup_expire_time.to_alipay_dict()
            else:
                params['last_signup_expire_time'] = self.last_signup_expire_time
        if self.last_signup_time:
            if hasattr(self.last_signup_time, 'to_alipay_dict'):
                params['last_signup_time'] = self.last_signup_time.to_alipay_dict()
            else:
                params['last_signup_time'] = self.last_signup_time
        if self.need_sign_up:
            if hasattr(self.need_sign_up, 'to_alipay_dict'):
                params['need_sign_up'] = self.need_sign_up.to_alipay_dict()
            else:
                params['need_sign_up'] = self.need_sign_up
        if self.period_current_complete_num:
            if hasattr(self.period_current_complete_num, 'to_alipay_dict'):
                params['period_current_complete_num'] = self.period_current_complete_num.to_alipay_dict()
            else:
                params['period_current_complete_num'] = self.period_current_complete_num
        if self.period_total_complete_num:
            if hasattr(self.period_total_complete_num, 'to_alipay_dict'):
                params['period_total_complete_num'] = self.period_total_complete_num.to_alipay_dict()
            else:
                params['period_total_complete_num'] = self.period_total_complete_num
        if self.periodic_accessed_num:
            if hasattr(self.periodic_accessed_num, 'to_alipay_dict'):
                params['periodic_accessed_num'] = self.periodic_accessed_num.to_alipay_dict()
            else:
                params['periodic_accessed_num'] = self.periodic_accessed_num
        if self.periodic_dimension:
            if hasattr(self.periodic_dimension, 'to_alipay_dict'):
                params['periodic_dimension'] = self.periodic_dimension.to_alipay_dict()
            else:
                params['periodic_dimension'] = self.periodic_dimension
        if self.prize_detail_list:
            if isinstance(self.prize_detail_list, list):
                for i in range(0, len(self.prize_detail_list)):
                    element = self.prize_detail_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.prize_detail_list[i] = element.to_alipay_dict()
            if hasattr(self.prize_detail_list, 'to_alipay_dict'):
                params['prize_detail_list'] = self.prize_detail_list.to_alipay_dict()
            else:
                params['prize_detail_list'] = self.prize_detail_list
        if self.send_camp_trigger_type:
            if hasattr(self.send_camp_trigger_type, 'to_alipay_dict'):
                params['send_camp_trigger_type'] = self.send_camp_trigger_type.to_alipay_dict()
            else:
                params['send_camp_trigger_type'] = self.send_camp_trigger_type
        if self.task_base_info:
            if hasattr(self.task_base_info, 'to_alipay_dict'):
                params['task_base_info'] = self.task_base_info.to_alipay_dict()
            else:
                params['task_base_info'] = self.task_base_info
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        if self.task_material:
            if hasattr(self.task_material, 'to_alipay_dict'):
                params['task_material'] = self.task_material.to_alipay_dict()
            else:
                params['task_material'] = self.task_material
        if self.task_process_status:
            if hasattr(self.task_process_status, 'to_alipay_dict'):
                params['task_process_status'] = self.task_process_status.to_alipay_dict()
            else:
                params['task_process_status'] = self.task_process_status
        if self.valid_prize_list:
            if isinstance(self.valid_prize_list, list):
                for i in range(0, len(self.valid_prize_list)):
                    element = self.valid_prize_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.valid_prize_list[i] = element.to_alipay_dict()
            if hasattr(self.valid_prize_list, 'to_alipay_dict'):
                params['valid_prize_list'] = self.valid_prize_list.to_alipay_dict()
            else:
                params['valid_prize_list'] = self.valid_prize_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TaskFullInfo()
        if 'access_limit_count' in d:
            o.access_limit_count = d['access_limit_count']
        if 'last_acc_time' in d:
            o.last_acc_time = d['last_acc_time']
        if 'last_complete_time' in d:
            o.last_complete_time = d['last_complete_time']
        if 'last_receive_expire_time' in d:
            o.last_receive_expire_time = d['last_receive_expire_time']
        if 'last_signup_expire_time' in d:
            o.last_signup_expire_time = d['last_signup_expire_time']
        if 'last_signup_time' in d:
            o.last_signup_time = d['last_signup_time']
        if 'need_sign_up' in d:
            o.need_sign_up = d['need_sign_up']
        if 'period_current_complete_num' in d:
            o.period_current_complete_num = d['period_current_complete_num']
        if 'period_total_complete_num' in d:
            o.period_total_complete_num = d['period_total_complete_num']
        if 'periodic_accessed_num' in d:
            o.periodic_accessed_num = d['periodic_accessed_num']
        if 'periodic_dimension' in d:
            o.periodic_dimension = d['periodic_dimension']
        if 'prize_detail_list' in d:
            o.prize_detail_list = d['prize_detail_list']
        if 'send_camp_trigger_type' in d:
            o.send_camp_trigger_type = d['send_camp_trigger_type']
        if 'task_base_info' in d:
            o.task_base_info = d['task_base_info']
        if 'task_id' in d:
            o.task_id = d['task_id']
        if 'task_material' in d:
            o.task_material = d['task_material']
        if 'task_process_status' in d:
            o.task_process_status = d['task_process_status']
        if 'valid_prize_list' in d:
            o.valid_prize_list = d['valid_prize_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PriceInfo(object):

    def __init__(self):
        self._dimension = None
        self._price = None

    @property
    def dimension(self):
        return self._dimension

    @dimension.setter
    def dimension(self, value):
        self._dimension = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value


    def to_alipay_dict(self):
        params = dict()
        if self.dimension:
            if hasattr(self.dimension, 'to_alipay_dict'):
                params['dimension'] = self.dimension.to_alipay_dict()
            else:
                params['dimension'] = self.dimension
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PriceInfo()
        if 'dimension' in d:
            o.dimension = d['dimension']
        if 'price' in d:
            o.price = d['price']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ConsumerProfile(object):

    def __init__(self):
        self._consumer_profile = None

    @property
    def consumer_profile(self):
        return self._consumer_profile

    @consumer_profile.setter
    def consumer_profile(self, value):
        self._consumer_profile = value


    def to_alipay_dict(self):
        params = dict()
        if self.consumer_profile:
            if hasattr(self.consumer_profile, 'to_alipay_dict'):
                params['consumer_profile'] = self.consumer_profile.to_alipay_dict()
            else:
                params['consumer_profile'] = self.consumer_profile
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ConsumerProfile()
        if 'consumer_profile' in d:
            o.consumer_profile = d['consumer_profile']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenOpenbizmockPidwhiteModifyModel(object):

    def __init__(self):
        self._app_number = None

    @property
    def app_number(self):
        return self._app_number

    @app_number.setter
    def app_number(self, value):
        self._app_number = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_number:
            if hasattr(self.app_number, 'to_alipay_dict'):
                params['app_number'] = self.app_number.to_alipay_dict()
            else:
                params['app_number'] = self.app_number
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenOpenbizmockPidwhiteModifyModel()
        if 'app_number' in d:
            o.app_number = d['app_number']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityProdEdgeColorfeedbackCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdEdgeColorfeedbackCreateResponse, self).__init__()
        self._trace = None

    @property
    def trace(self):
        return self._trace

    @trace.setter
    def trace(self, value):
        self._trace = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdEdgeColorfeedbackCreateResponse, self).parse_response_content(response_content)
        if 'trace' in response:
            self.trace = response['trace']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.OpenBudget import OpenBudget


class OpenFundInfo(object):

    def __init__(self):
        self._budget = None
        self._ceiling_amount = None
        self._display_account = None
        self._fund_account = None
        self._fund_mode = None
        self._fund_provider = None
        self._fund_ratio = None
        self._fund_related_id = None
        self._fund_source_type = None
        self._fund_type = None
        self._item_ceiling_amount = None
        self._item_merchant_subsidy_rounding_mode = None
        self._minitrans_account = None
        self._point_budget_code = None
        self._recharge_freeze_code = None
        self._recharge_type = None
        self._refund_account = None
        self._refund_funding_priority = None

    @property
    def budget(self):
        return self._budget

    @budget.setter
    def budget(self, value):
        if isinstance(value, OpenBudget):
            self._budget = value
        else:
            self._budget = OpenBudget.from_alipay_dict(value)
    @property
    def ceiling_amount(self):
        return self._ceiling_amount

    @ceiling_amount.setter
    def ceiling_amount(self, value):
        self._ceiling_amount = value
    @property
    def display_account(self):
        return self._display_account

    @display_account.setter
    def display_account(self, value):
        self._display_account = value
    @property
    def fund_account(self):
        return self._fund_account

    @fund_account.setter
    def fund_account(self, value):
        self._fund_account = value
    @property
    def fund_mode(self):
        return self._fund_mode

    @fund_mode.setter
    def fund_mode(self, value):
        self._fund_mode = value
    @property
    def fund_provider(self):
        return self._fund_provider

    @fund_provider.setter
    def fund_provider(self, value):
        self._fund_provider = value
    @property
    def fund_ratio(self):
        return self._fund_ratio

    @fund_ratio.setter
    def fund_ratio(self, value):
        self._fund_ratio = value
    @property
    def fund_related_id(self):
        return self._fund_related_id

    @fund_related_id.setter
    def fund_related_id(self, value):
        self._fund_related_id = value
    @property
    def fund_source_type(self):
        return self._fund_source_type

    @fund_source_type.setter
    def fund_source_type(self, value):
        self._fund_source_type = value
    @property
    def fund_type(self):
        return self._fund_type

    @fund_type.setter
    def fund_type(self, value):
        self._fund_type = value
    @property
    def item_ceiling_amount(self):
        return self._item_ceiling_amount

    @item_ceiling_amount.setter
    def item_ceiling_amount(self, value):
        self._item_ceiling_amount = value
    @property
    def item_merchant_subsidy_rounding_mode(self):
        return self._item_merchant_subsidy_rounding_mode

    @item_merchant_subsidy_rounding_mode.setter
    def item_merchant_subsidy_rounding_mode(self, value):
        self._item_merchant_subsidy_rounding_mode = value
    @property
    def minitrans_account(self):
        return self._minitrans_account

    @minitrans_account.setter
    def minitrans_account(self, value):
        self._minitrans_account = value
    @property
    def point_budget_code(self):
        return self._point_budget_code

    @point_budget_code.setter
    def point_budget_code(self, value):
        self._point_budget_code = value
    @property
    def recharge_freeze_code(self):
        return self._recharge_freeze_code

    @recharge_freeze_code.setter
    def recharge_freeze_code(self, value):
        self._recharge_freeze_code = value
    @property
    def recharge_type(self):
        return self._recharge_type

    @recharge_type.setter
    def recharge_type(self, value):
        self._recharge_type = value
    @property
    def refund_account(self):
        return self._refund_account

    @refund_account.setter
    def refund_account(self, value):
        self._refund_account = value
    @property
    def refund_funding_priority(self):
        return self._refund_funding_priority

    @refund_funding_priority.setter
    def refund_funding_priority(self, value):
        self._refund_funding_priority = value


    def to_alipay_dict(self):
        params = dict()
        if self.budget:
            if hasattr(self.budget, 'to_alipay_dict'):
                params['budget'] = self.budget.to_alipay_dict()
            else:
                params['budget'] = self.budget
        if self.ceiling_amount:
            if hasattr(self.ceiling_amount, 'to_alipay_dict'):
                params['ceiling_amount'] = self.ceiling_amount.to_alipay_dict()
            else:
                params['ceiling_amount'] = self.ceiling_amount
        if self.display_account:
            if hasattr(self.display_account, 'to_alipay_dict'):
                params['display_account'] = self.display_account.to_alipay_dict()
            else:
                params['display_account'] = self.display_account
        if self.fund_account:
            if hasattr(self.fund_account, 'to_alipay_dict'):
                params['fund_account'] = self.fund_account.to_alipay_dict()
            else:
                params['fund_account'] = self.fund_account
        if self.fund_mode:
            if hasattr(self.fund_mode, 'to_alipay_dict'):
                params['fund_mode'] = self.fund_mode.to_alipay_dict()
            else:
                params['fund_mode'] = self.fund_mode
        if self.fund_provider:
            if hasattr(self.fund_provider, 'to_alipay_dict'):
                params['fund_provider'] = self.fund_provider.to_alipay_dict()
            else:
                params['fund_provider'] = self.fund_provider
        if self.fund_ratio:
            if hasattr(self.fund_ratio, 'to_alipay_dict'):
                params['fund_ratio'] = self.fund_ratio.to_alipay_dict()
            else:
                params['fund_ratio'] = self.fund_ratio
        if self.fund_related_id:
            if hasattr(self.fund_related_id, 'to_alipay_dict'):
                params['fund_related_id'] = self.fund_related_id.to_alipay_dict()
            else:
                params['fund_related_id'] = self.fund_related_id
        if self.fund_source_type:
            if hasattr(self.fund_source_type, 'to_alipay_dict'):
                params['fund_source_type'] = self.fund_source_type.to_alipay_dict()
            else:
                params['fund_source_type'] = self.fund_source_type
        if self.fund_type:
            if hasattr(self.fund_type, 'to_alipay_dict'):
                params['fund_type'] = self.fund_type.to_alipay_dict()
            else:
                params['fund_type'] = self.fund_type
        if self.item_ceiling_amount:
            if hasattr(self.item_ceiling_amount, 'to_alipay_dict'):
                params['item_ceiling_amount'] = self.item_ceiling_amount.to_alipay_dict()
            else:
                params['item_ceiling_amount'] = self.item_ceiling_amount
        if self.item_merchant_subsidy_rounding_mode:
            if hasattr(self.item_merchant_subsidy_rounding_mode, 'to_alipay_dict'):
                params['item_merchant_subsidy_rounding_mode'] = self.item_merchant_subsidy_rounding_mode.to_alipay_dict()
            else:
                params['item_merchant_subsidy_rounding_mode'] = self.item_merchant_subsidy_rounding_mode
        if self.minitrans_account:
            if hasattr(self.minitrans_account, 'to_alipay_dict'):
                params['minitrans_account'] = self.minitrans_account.to_alipay_dict()
            else:
                params['minitrans_account'] = self.minitrans_account
        if self.point_budget_code:
            if hasattr(self.point_budget_code, 'to_alipay_dict'):
                params['point_budget_code'] = self.point_budget_code.to_alipay_dict()
            else:
                params['point_budget_code'] = self.point_budget_code
        if self.recharge_freeze_code:
            if hasattr(self.recharge_freeze_code, 'to_alipay_dict'):
                params['recharge_freeze_code'] = self.recharge_freeze_code.to_alipay_dict()
            else:
                params['recharge_freeze_code'] = self.recharge_freeze_code
        if self.recharge_type:
            if hasattr(self.recharge_type, 'to_alipay_dict'):
                params['recharge_type'] = self.recharge_type.to_alipay_dict()
            else:
                params['recharge_type'] = self.recharge_type
        if self.refund_account:
            if hasattr(self.refund_account, 'to_alipay_dict'):
                params['refund_account'] = self.refund_account.to_alipay_dict()
            else:
                params['refund_account'] = self.refund_account
        if self.refund_funding_priority:
            if hasattr(self.refund_funding_priority, 'to_alipay_dict'):
                params['refund_funding_priority'] = self.refund_funding_priority.to_alipay_dict()
            else:
                params['refund_funding_priority'] = self.refund_funding_priority
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenFundInfo()
        if 'budget' in d:
            o.budget = d['budget']
        if 'ceiling_amount' in d:
            o.ceiling_amount = d['ceiling_amount']
        if 'display_account' in d:
            o.display_account = d['display_account']
        if 'fund_account' in d:
            o.fund_account = d['fund_account']
        if 'fund_mode' in d:
            o.fund_mode = d['fund_mode']
        if 'fund_provider' in d:
            o.fund_provider = d['fund_provider']
        if 'fund_ratio' in d:
            o.fund_ratio = d['fund_ratio']
        if 'fund_related_id' in d:
            o.fund_related_id = d['fund_related_id']
        if 'fund_source_type' in d:
            o.fund_source_type = d['fund_source_type']
        if 'fund_type' in d:
            o.fund_type = d['fund_type']
        if 'item_ceiling_amount' in d:
            o.item_ceiling_amount = d['item_ceiling_amount']
        if 'item_merchant_subsidy_rounding_mode' in d:
            o.item_merchant_subsidy_rounding_mode = d['item_merchant_subsidy_rounding_mode']
        if 'minitrans_account' in d:
            o.minitrans_account = d['minitrans_account']
        if 'point_budget_code' in d:
            o.point_budget_code = d['point_budget_code']
        if 'recharge_freeze_code' in d:
            o.recharge_freeze_code = d['recharge_freeze_code']
        if 'recharge_type' in d:
            o.recharge_type = d['recharge_type']
        if 'refund_account' in d:
            o.refund_account = d['refund_account']
        if 'refund_funding_priority' in d:
            o.refund_funding_priority = d['refund_funding_priority']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserGamecenterHistorygameactionSubmitModel(object):

    def __init__(self):
        self._action_code = None
        self._action_finish_channel = None
        self._action_finish_date = None
        self._alipay_user_id = None
        self._open_id = None
        self._out_biz_no = None

    @property
    def action_code(self):
        return self._action_code

    @action_code.setter
    def action_code(self, value):
        self._action_code = value
    @property
    def action_finish_channel(self):
        return self._action_finish_channel

    @action_finish_channel.setter
    def action_finish_channel(self, value):
        self._action_finish_channel = value
    @property
    def action_finish_date(self):
        return self._action_finish_date

    @action_finish_date.setter
    def action_finish_date(self, value):
        self._action_finish_date = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_code:
            if hasattr(self.action_code, 'to_alipay_dict'):
                params['action_code'] = self.action_code.to_alipay_dict()
            else:
                params['action_code'] = self.action_code
        if self.action_finish_channel:
            if hasattr(self.action_finish_channel, 'to_alipay_dict'):
                params['action_finish_channel'] = self.action_finish_channel.to_alipay_dict()
            else:
                params['action_finish_channel'] = self.action_finish_channel
        if self.action_finish_date:
            if hasattr(self.action_finish_date, 'to_alipay_dict'):
                params['action_finish_date'] = self.action_finish_date.to_alipay_dict()
            else:
                params['action_finish_date'] = self.action_finish_date
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserGamecenterHistorygameactionSubmitModel()
        if 'action_code' in d:
            o.action_code = d['action_code']
        if 'action_finish_channel' in d:
            o.action_finish_channel = d['action_finish_channel']
        if 'action_finish_date' in d:
            o.action_finish_date = d['action_finish_date']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OpenVoucherDTO import OpenVoucherDTO


class AlipayMarketingVoucherExchangevoucherRefundResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingVoucherExchangevoucherRefundResponse, self).__init__()
        self._voucher = None

    @property
    def voucher(self):
        return self._voucher

    @voucher.setter
    def voucher(self, value):
        if isinstance(value, OpenVoucherDTO):
            self._voucher = value
        else:
            self._voucher = OpenVoucherDTO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingVoucherExchangevoucherRefundResponse, self).parse_response_content(response_content)
        if 'voucher' in response:
            self.voucher = response['voucher']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ReportInfo(object):

    def __init__(self):
        self._case_no = None
        self._case_status = None
        self._case_times = None
        self._end_case_amount = None
        self._end_case_date = None
        self._indemnity_conclusion = None
        self._pay_date = None
        self._policy_no = None
        self._product_name = None
        self._report_date = None
        self._report_no = None

    @property
    def case_no(self):
        return self._case_no

    @case_no.setter
    def case_no(self, value):
        self._case_no = value
    @property
    def case_status(self):
        return self._case_status

    @case_status.setter
    def case_status(self, value):
        self._case_status = value
    @property
    def case_times(self):
        return self._case_times

    @case_times.setter
    def case_times(self, value):
        self._case_times = value
    @property
    def end_case_amount(self):
        return self._end_case_amount

    @end_case_amount.setter
    def end_case_amount(self, value):
        self._end_case_amount = value
    @property
    def end_case_date(self):
        return self._end_case_date

    @end_case_date.setter
    def end_case_date(self, value):
        self._end_case_date = value
    @property
    def indemnity_conclusion(self):
        return self._indemnity_conclusion

    @indemnity_conclusion.setter
    def indemnity_conclusion(self, value):
        self._indemnity_conclusion = value
    @property
    def pay_date(self):
        return self._pay_date

    @pay_date.setter
    def pay_date(self, value):
        self._pay_date = value
    @property
    def policy_no(self):
        return self._policy_no

    @policy_no.setter
    def policy_no(self, value):
        self._policy_no = value
    @property
    def product_name(self):
        return self._product_name

    @product_name.setter
    def product_name(self, value):
        self._product_name = value
    @property
    def report_date(self):
        return self._report_date

    @report_date.setter
    def report_date(self, value):
        self._report_date = value
    @property
    def report_no(self):
        return self._report_no

    @report_no.setter
    def report_no(self, value):
        self._report_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.case_no:
            if hasattr(self.case_no, 'to_alipay_dict'):
                params['case_no'] = self.case_no.to_alipay_dict()
            else:
                params['case_no'] = self.case_no
        if self.case_status:
            if hasattr(self.case_status, 'to_alipay_dict'):
                params['case_status'] = self.case_status.to_alipay_dict()
            else:
                params['case_status'] = self.case_status
        if self.case_times:
            if hasattr(self.case_times, 'to_alipay_dict'):
                params['case_times'] = self.case_times.to_alipay_dict()
            else:
                params['case_times'] = self.case_times
        if self.end_case_amount:
            if hasattr(self.end_case_amount, 'to_alipay_dict'):
                params['end_case_amount'] = self.end_case_amount.to_alipay_dict()
            else:
                params['end_case_amount'] = self.end_case_amount
        if self.end_case_date:
            if hasattr(self.end_case_date, 'to_alipay_dict'):
                params['end_case_date'] = self.end_case_date.to_alipay_dict()
            else:
                params['end_case_date'] = self.end_case_date
        if self.indemnity_conclusion:
            if hasattr(self.indemnity_conclusion, 'to_alipay_dict'):
                params['indemnity_conclusion'] = self.indemnity_conclusion.to_alipay_dict()
            else:
                params['indemnity_conclusion'] = self.indemnity_conclusion
        if self.pay_date:
            if hasattr(self.pay_date, 'to_alipay_dict'):
                params['pay_date'] = self.pay_date.to_alipay_dict()
            else:
                params['pay_date'] = self.pay_date
        if self.policy_no:
            if hasattr(self.policy_no, 'to_alipay_dict'):
                params['policy_no'] = self.policy_no.to_alipay_dict()
            else:
                params['policy_no'] = self.policy_no
        if self.product_name:
            if hasattr(self.product_name, 'to_alipay_dict'):
                params['product_name'] = self.product_name.to_alipay_dict()
            else:
                params['product_name'] = self.product_name
        if self.report_date:
            if hasattr(self.report_date, 'to_alipay_dict'):
                params['report_date'] = self.report_date.to_alipay_dict()
            else:
                params['report_date'] = self.report_date
        if self.report_no:
            if hasattr(self.report_no, 'to_alipay_dict'):
                params['report_no'] = self.report_no.to_alipay_dict()
            else:
                params['report_no'] = self.report_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ReportInfo()
        if 'case_no' in d:
            o.case_no = d['case_no']
        if 'case_status' in d:
            o.case_status = d['case_status']
        if 'case_times' in d:
            o.case_times = d['case_times']
        if 'end_case_amount' in d:
            o.end_case_amount = d['end_case_amount']
        if 'end_case_date' in d:
            o.end_case_date = d['end_case_date']
        if 'indemnity_conclusion' in d:
            o.indemnity_conclusion = d['indemnity_conclusion']
        if 'pay_date' in d:
            o.pay_date = d['pay_date']
        if 'policy_no' in d:
            o.policy_no = d['policy_no']
        if 'product_name' in d:
            o.product_name = d['product_name']
        if 'report_date' in d:
            o.report_date = d['report_date']
        if 'report_no' in d:
            o.report_no = d['report_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceIotMdeviceprodAssetapplyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceIotMdeviceprodAssetapplyQueryResponse, self).__init__()
        self._apply_isv_name = None
        self._apply_isv_pid = None
        self._apply_merchant_mobile = None
        self._apply_merchant_name = None
        self._apply_merchant_pid = None
        self._apply_person_mobile = None
        self._apply_person_name = None
        self._detail_info = None
        self._first_apply = None
        self._shop_id = None
        self._shop_name = None

    @property
    def apply_isv_name(self):
        return self._apply_isv_name

    @apply_isv_name.setter
    def apply_isv_name(self, value):
        self._apply_isv_name = value
    @property
    def apply_isv_pid(self):
        return self._apply_isv_pid

    @apply_isv_pid.setter
    def apply_isv_pid(self, value):
        self._apply_isv_pid = value
    @property
    def apply_merchant_mobile(self):
        return self._apply_merchant_mobile

    @apply_merchant_mobile.setter
    def apply_merchant_mobile(self, value):
        self._apply_merchant_mobile = value
    @property
    def apply_merchant_name(self):
        return self._apply_merchant_name

    @apply_merchant_name.setter
    def apply_merchant_name(self, value):
        self._apply_merchant_name = value
    @property
    def apply_merchant_pid(self):
        return self._apply_merchant_pid

    @apply_merchant_pid.setter
    def apply_merchant_pid(self, value):
        self._apply_merchant_pid = value
    @property
    def apply_person_mobile(self):
        return self._apply_person_mobile

    @apply_person_mobile.setter
    def apply_person_mobile(self, value):
        self._apply_person_mobile = value
    @property
    def apply_person_name(self):
        return self._apply_person_name

    @apply_person_name.setter
    def apply_person_name(self, value):
        self._apply_person_name = value
    @property
    def detail_info(self):
        return self._detail_info

    @detail_info.setter
    def detail_info(self, value):
        self._detail_info = value
    @property
    def first_apply(self):
        return self._first_apply

    @first_apply.setter
    def first_apply(self, value):
        self._first_apply = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceIotMdeviceprodAssetapplyQueryResponse, self).parse_response_content(response_content)
        if 'apply_isv_name' in response:
            self.apply_isv_name = response['apply_isv_name']
        if 'apply_isv_pid' in response:
            self.apply_isv_pid = response['apply_isv_pid']
        if 'apply_merchant_mobile' in response:
            self.apply_merchant_mobile = response['apply_merchant_mobile']
        if 'apply_merchant_name' in response:
            self.apply_merchant_name = response['apply_merchant_name']
        if 'apply_merchant_pid' in response:
            self.apply_merchant_pid = response['apply_merchant_pid']
        if 'apply_person_mobile' in response:
            self.apply_person_mobile = response['apply_person_mobile']
        if 'apply_person_name' in response:
            self.apply_person_name = response['apply_person_name']
        if 'detail_info' in response:
            self.detail_info = response['detail_info']
        if 'first_apply' in response:
            self.first_apply = response['first_apply']
        if 'shop_id' in response:
            self.shop_id = response['shop_id']
        if 'shop_name' in response:
            self.shop_name = response['shop_name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InsEndorseItem import InsEndorseItem


class AlipayInsScenePolicyEndorseApplyModel(object):

    def __init__(self):
        self._endorse_items = None
        self._out_request_no = None
        self._policy_no = None
        self._source = None

    @property
    def endorse_items(self):
        return self._endorse_items

    @endorse_items.setter
    def endorse_items(self, value):
        if isinstance(value, list):
            self._endorse_items = list()
            for i in value:
                if isinstance(i, InsEndorseItem):
                    self._endorse_items.append(i)
                else:
                    self._endorse_items.append(InsEndorseItem.from_alipay_dict(i))
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def policy_no(self):
        return self._policy_no

    @policy_no.setter
    def policy_no(self, value):
        self._policy_no = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value


    def to_alipay_dict(self):
        params = dict()
        if self.endorse_items:
            if isinstance(self.endorse_items, list):
                for i in range(0, len(self.endorse_items)):
                    element = self.endorse_items[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.endorse_items[i] = element.to_alipay_dict()
            if hasattr(self.endorse_items, 'to_alipay_dict'):
                params['endorse_items'] = self.endorse_items.to_alipay_dict()
            else:
                params['endorse_items'] = self.endorse_items
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.policy_no:
            if hasattr(self.policy_no, 'to_alipay_dict'):
                params['policy_no'] = self.policy_no.to_alipay_dict()
            else:
                params['policy_no'] = self.policy_no
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsScenePolicyEndorseApplyModel()
        if 'endorse_items' in d:
            o.endorse_items = d['endorse_items']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'policy_no' in d:
            o.policy_no = d['policy_no']
        if 'source' in d:
            o.source = d['source']
        return o


